@@ -1020,9 +1020,16 @@ REGISTER_LOADER;
 
         if ($useIncludeFiles) {
             $file .= <<<INCLUDE_FILES
-        \$includeFiles = \Composer\Autoload\ComposerStaticInit$suffix::\$files;
-        foreach (\$includeFiles as \$fileIdentifier => \$file) {
-            composerRequire$suffix(\$fileIdentifier, \$file);
+        \$filesToLoad = \Composer\Autoload\ComposerStaticInit$suffix::\$files;
+        \$requireFile = \Closure::bind(static function (\$fileIdentifier, \$file) {
+            if (empty(\$GLOBALS['__composer_autoload_files'][\$fileIdentifier])) {
+                \$GLOBALS['__composer_autoload_files'][\$fileIdentifier] = true;
+
+                require \$file;
+            }
+        }, null, null);
+        foreach (\$filesToLoad as \$fileIdentifier => \$file) {
+            \$requireFile(\$fileIdentifier, \$file);
         }
 
 
@@ -1037,27 +1044,6 @@ METHOD_FOOTER;
 
         $file .= $targetDirLoader;
 
-        if ($useIncludeFiles) {
-            return $file . <<<FOOTER
-}
-
-/**
- * @param string \$fileIdentifier
- * @param string \$file
- * @return void
- */
-function composerRequire$suffix(\$fileIdentifier, \$file)
-{
-    if (empty(\$GLOBALS['__composer_autoload_files'][\$fileIdentifier])) {
-        \$GLOBALS['__composer_autoload_files'][\$fileIdentifier] = true;
-
-        require \$file;
-    }
-}
-
-FOOTER;
-        }
-
         return $file . <<<FOOTER
 }
 
