@@ -24,8 +24,8 @@ use Composer\IO\IOInterface;
 use Composer\Downloader\FilesystemException;
 use Composer\Downloader\TransportException;
 use Symfony\Component\Console\Input\InputInterface;
-use Symfony\Component\Console\Input\InputOption;
-use Symfony\Component\Console\Input\InputArgument;
+use Composer\Console\Input\InputOption;
+use Composer\Console\Input\InputArgument;
 use Symfony\Component\Console\Output\OutputInterface;
 use Symfony\Component\Finder\Finder;
 
@@ -39,16 +39,13 @@ class SelfUpdateCommand extends BaseCommand
     private const HOMEPAGE = 'getcomposer.org';
     private const OLD_INSTALL_EXT = '-old.phar';
 
-    /**
-     * @return void
-     */
     protected function configure(): void
     {
         $this
             ->setName('self-update')
-            ->setAliases(array('selfupdate'))
-            ->setDescription('Updates composer.phar to the latest version.')
-            ->setDefinition(array(
+            ->setAliases(['selfupdate'])
+            ->setDescription('Updates composer.phar to the latest version')
+            ->setDefinition([
                 new InputOption('rollback', 'r', InputOption::VALUE_NONE, 'Revert to an older installation of composer'),
                 new InputOption('clean-backups', null, InputOption::VALUE_NONE, 'Delete old backups during an update. This makes the current version of composer the only backup available after the update'),
                 new InputArgument('version', InputArgument::OPTIONAL, 'The version to update to'),
@@ -61,7 +58,7 @@ class SelfUpdateCommand extends BaseCommand
                 new InputOption('2', null, InputOption::VALUE_NONE, 'Force an update to the stable channel, but only use 2.x versions'),
                 new InputOption('2.2', null, InputOption::VALUE_NONE, 'Force an update to the stable channel, but only use 2.2.x LTS versions'),
                 new InputOption('set-channel-only', null, InputOption::VALUE_NONE, 'Only store the channel as the default one and then exit'),
-            ))
+            ])
             ->setHelp(
                 <<<EOT
 The <info>self-update</info> command checks getcomposer.org for newer
@@ -69,7 +66,7 @@ versions of composer and if found, installs the latest.
 
 <info>php composer.phar self-update</info>
 
-Read more at https://getcomposer.org/doc/03-cli.md#self-update-selfupdate-
+Read more at https://getcomposer.org/doc/03-cli.md#self-update-selfupdate
 EOT
             )
         ;
@@ -361,7 +358,6 @@ TAGSPUBKEY
     }
 
     /**
-     * @return void
      * @throws \Exception
      */
     protected function fetchKeys(IOInterface $io, Config $config): void
@@ -372,7 +368,8 @@ TAGSPUBKEY
 
         $io->write('Open <info>https://composer.github.io/pubkeys.html</info> to find the latest keys');
 
-        $validator = function ($value): string {
+        $validator = static function ($value): string {
+            $value = (string) $value;
             if (!Preg::isMatch('{^-----BEGIN PUBLIC KEY-----$}', trim($value))) {
                 throw new \UnexpectedValueException('Invalid input');
             }
@@ -383,7 +380,7 @@ TAGSPUBKEY
         $devKey = '';
         while (!Preg::isMatch('{(-----BEGIN PUBLIC KEY-----.+?-----END PUBLIC KEY-----)}s', $devKey, $match)) {
             $devKey = $io->askAndValidate('Enter Dev / Snapshot Public Key (including lines with -----): ', $validator);
-            while ($line = $io->ask('')) {
+            while ($line = $io->ask('', '')) {
                 $devKey .= trim($line)."\n";
                 if (trim($line) === '-----END PUBLIC KEY-----') {
                     break;
@@ -396,7 +393,7 @@ TAGSPUBKEY
         $tagsKey = '';
         while (!Preg::isMatch('{(-----BEGIN PUBLIC KEY-----.+?-----END PUBLIC KEY-----)}s', $tagsKey, $match)) {
             $tagsKey = $io->askAndValidate('Enter Tags Public Key (including lines with -----): ', $validator);
-            while ($line = $io->ask('')) {
+            while ($line = $io->ask('', '')) {
                 $tagsKey .= trim($line)."\n";
                 if (trim($line) === '-----END PUBLIC KEY-----') {
                     break;
@@ -410,9 +407,6 @@ TAGSPUBKEY
     }
 
     /**
-     * @param string $rollbackDir
-     * @param string $localFilename
-     * @return int
      * @throws FilesystemException
      */
     protected function rollback(OutputInterface $output, string $rollbackDir, string $localFilename): int
@@ -449,7 +443,7 @@ TAGSPUBKEY
      * @throws FilesystemException If the file cannot be moved
      * @return bool                Whether the phar is valid and has been moved
      */
-    protected function setLocalPhar(string $localFilename, string $newFilename, string $backupTarget = null): bool
+    protected function setLocalPhar(string $localFilename, string $newFilename, ?string $backupTarget = null): bool
     {
         $io = $this->getIO();
         $perms = @fileperms($localFilename);
@@ -498,12 +492,6 @@ TAGSPUBKEY
         }
     }
 
-    /**
-     * @param string $rollbackDir
-     * @param string|null $except
-     *
-     * @return void
-     */
     protected function cleanBackups(string $rollbackDir, ?string $except = null): void
     {
         $finder = $this->getOldInstallationFinder($rollbackDir);
@@ -533,10 +521,6 @@ TAGSPUBKEY
         return null;
     }
 
-    /**
-     * @param string $rollbackDir
-     * @return Finder
-     */
     protected function getOldInstallationFinder(string $rollbackDir): Finder
     {
         return Finder::create()
@@ -583,8 +567,6 @@ TAGSPUBKEY
 
     /**
      * Returns true if this is a non-admin Windows user account
-     *
-     * @return bool
      */
     protected function isWindowsNonAdminUser(): bool
     {
@@ -615,7 +597,7 @@ TAGSPUBKEY
         $helpMessage = 'Please run the self-update command as an Administrator.';
         $question = 'Complete this operation with Administrator privileges [<comment>Y,n</comment>]? ';
 
-        if (!$io->askConfirmation($question, false)) {
+        if (!$io->askConfirmation($question, true)) {
             $io->writeError('<warning>Operation cancelled. '.$helpMessage.'</warning>');
 
             return false;
