@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -27,12 +27,12 @@ class DefaultPolicy implements PolicyInterface
     private $preferStable;
     /** @var bool */
     private $preferLowest;
+    /** @var array<int, array<string, array<int, int>>> */
+    private $preferredPackageResultCachePerPool;
+    /** @var array<int, array<string, int>> */
+    private $sortingCachePerPool;
 
-    /**
-     * @param bool $preferStable
-     * @param bool $preferLowest
-     */
-    public function __construct($preferStable = false, $preferLowest = false)
+    public function __construct(bool $preferStable = false, bool $preferLowest = false)
     {
         $this->preferStable = $preferStable;
         $this->preferLowest = $preferLowest;
@@ -40,11 +40,10 @@ class DefaultPolicy implements PolicyInterface
 
     /**
      * @param string $operator One of Constraint::STR_OP_*
-     * @return bool
      *
      * @phpstan-param Constraint::STR_OP_* $operator
      */
-    public function versionCompare(PackageInterface $a, PackageInterface $b, $operator)
+    public function versionCompare(PackageInterface $a, PackageInterface $b, string $operator): bool
     {
         if ($this->preferStable && ($stabA = $a->getStability()) !== ($stabB = $b->getStability())) {
             return BasePackage::$stabilities[$stabA] < BasePackage::$stabilities[$stabB];
@@ -61,14 +60,27 @@ class DefaultPolicy implements PolicyInterface
      * @param  string $requiredPackage
      * @return int[]
      */
-    public function selectPreferredPackages(Pool $pool, array $literals, $requiredPackage = null)
+    public function selectPreferredPackages(Pool $pool, array $literals, ?string $requiredPackage = null): array
     {
+        sort($literals);
+        $resultCacheKey = implode(',', $literals).$requiredPackage;
+        $poolId = spl_object_id($pool);
+
+        if (isset($this->preferredPackageResultCachePerPool[$poolId][$resultCacheKey])) {
+            return $this->preferredPackageResultCachePerPool[$poolId][$resultCacheKey];
+        }
+
         $packages = $this->groupLiteralsByName($pool, $literals);
-        $policy = $this;
 
         foreach ($packages as &$nameLiterals) {
-            usort($nameLiterals, function ($a, $b) use ($policy, $pool, $requiredPackage) {
-                return $policy->compareByPriority($pool, $pool->literalToPackage($a), $pool->literalToPackage($b), $requiredPackage, true);
+            usort($nameLiterals, function ($a, $b) use ($pool, $requiredPackage, $poolId): int {
+                $cacheKey = 'i'.$a.'.'.$b.$requiredPackage; // i prefix -> ignoreReplace = true
+
+                if (isset($this->sortingCachePerPool[$poolId][$cacheKey])) {
+                    return $this->sortingCachePerPool[$poolId][$cacheKey];
+                }
+
+                return $this->sortingCachePerPool[$poolId][$cacheKey] = $this->compareByPriority($pool, $pool->literalToPackage($a), $pool->literalToPackage($b), $requiredPackage, true);
             });
         }
 
@@ -77,28 +89,34 @@ class DefaultPolicy implements PolicyInterface
             $sortedLiterals = $this->pruneRemoteAliases($pool, $sortedLiterals);
         }
 
-        $selected = \call_user_func_array('array_merge', array_values($packages));
+        $selected = array_merge(...array_values($packages));
 
         // now sort the result across all packages to respect replaces across packages
-        usort($selected, function ($a, $b) use ($policy, $pool, $requiredPackage) {
-            return $policy->compareByPriority($pool, $pool->literalToPackage($a), $pool->literalToPackage($b), $requiredPackage);
+        usort($selected, function ($a, $b) use ($pool, $requiredPackage, $poolId): int {
+            $cacheKey = $a.'.'.$b.$requiredPackage; // no i prefix -> ignoreReplace = false
+
+            if (isset($this->sortingCachePerPool[$poolId][$cacheKey])) {
+                return $this->sortingCachePerPool[$poolId][$cacheKey];
+            }
+
+            return $this->sortingCachePerPool[$poolId][$cacheKey] = $this->compareByPriority($pool, $pool->literalToPackage($a), $pool->literalToPackage($b), $requiredPackage);
         });
 
-        return $selected;
+        return $this->preferredPackageResultCachePerPool[$poolId][$resultCacheKey] = $selected;
     }
 
     /**
      * @param  int[] $literals
      * @return array<string, int[]>
      */
-    protected function groupLiteralsByName(Pool $pool, $literals)
+    protected function groupLiteralsByName(Pool $pool, array $literals): array
     {
-        $packages = array();
+        $packages = [];
         foreach ($literals as $literal) {
             $packageName = $pool->literalToPackage($literal)->getName();
 
             if (!isset($packages[$packageName])) {
-                $packages[$packageName] = array();
+                $packages[$packageName] = [];
             }
             $packages[$packageName][] = $literal;
         }
@@ -108,11 +126,8 @@ class DefaultPolicy implements PolicyInterface
 
     /**
      * @protected
-     * @param ?string $requiredPackage
-     * @param bool $ignoreReplace
-     * @return int
      */
-    public function compareByPriority(Pool $pool, BasePackage $a, BasePackage $b, $requiredPackage = null, $ignoreReplace = false)
+    public function compareByPriority(Pool $pool, BasePackage $a, BasePackage $b, ?string $requiredPackage = null, bool $ignoreReplace = false): int
     {
         // prefer aliases to the original package
         if ($a->getName() === $b->getName()) {
@@ -162,16 +177,14 @@ class DefaultPolicy implements PolicyInterface
      *
      * Replace constraints are ignored. This method should only be used for
      * prioritisation, not for actual constraint verification.
-     *
-     * @return bool
      */
-    protected function replaces(BasePackage $source, BasePackage $target)
+    protected function replaces(BasePackage $source, BasePackage $target): bool
     {
         foreach ($source->getReplaces() as $link) {
             if ($link->getTarget() === $target->getName()
 //                && (null === $link->getConstraint() ||
 //                $link->getConstraint()->matches(new Constraint('==', $target->getVersion())))) {
-                ) {
+            ) {
                 return true;
             }
         }
@@ -183,10 +196,10 @@ class DefaultPolicy implements PolicyInterface
      * @param  int[] $literals
      * @return int[]
      */
-    protected function pruneToBestVersion(Pool $pool, $literals)
+    protected function pruneToBestVersion(Pool $pool, array $literals): array
     {
         $operator = $this->preferLowest ? '<' : '>';
-        $bestLiterals = array($literals[0]);
+        $bestLiterals = [$literals[0]];
         $bestPackage = $pool->literalToPackage($literals[0]);
         foreach ($literals as $i => $literal) {
             if (0 === $i) {
@@ -197,7 +210,7 @@ class DefaultPolicy implements PolicyInterface
 
             if ($this->versionCompare($package, $bestPackage, $operator)) {
                 $bestPackage = $package;
-                $bestLiterals = array($literal);
+                $bestLiterals = [$literal];
             } elseif ($this->versionCompare($package, $bestPackage, '==')) {
                 $bestLiterals[] = $literal;
             }
@@ -214,7 +227,7 @@ class DefaultPolicy implements PolicyInterface
      * @param  int[] $literals
      * @return int[]
      */
-    protected function pruneRemoteAliases(Pool $pool, array $literals)
+    protected function pruneRemoteAliases(Pool $pool, array $literals): array
     {
         $hasLocalAlias = false;
 
@@ -231,7 +244,7 @@ class DefaultPolicy implements PolicyInterface
             return $literals;
         }
 
-        $selected = array();
+        $selected = [];
         foreach ($literals as $literal) {
             $package = $pool->literalToPackage($literal);
 
