@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -43,7 +43,7 @@ class Problem
      * A set of reasons for the problem, each is a rule or a root require and a rule
      * @var array<int, array<int, Rule>>
      */
-    protected $reasons = array();
+    protected $reasons = [];
 
     /** @var int */
     protected $section = 0;
@@ -52,9 +52,8 @@ class Problem
      * Add a rule as a reason
      *
      * @param Rule $rule A rule which is a reason for this problem
-     * @return void
      */
-    public function addRule(Rule $rule)
+    public function addRule(Rule $rule): void
     {
         $this->addReason(spl_object_hash($rule), $rule);
     }
@@ -64,7 +63,7 @@ class Problem
      *
      * @return array<int, array<int, Rule>> The problem's reasons
      */
-    public function getReasons()
+    public function getReasons(): array
     {
         return $this->reasons;
     }
@@ -72,35 +71,28 @@ class Problem
     /**
      * A human readable textual representation of the problem's reasons
      *
-     * @param bool $isVerbose
      * @param array<int|string, BasePackage> $installedMap A map of all present packages
      * @param array<Rule[]> $learnedPool
-     * @return string
      */
-    public function getPrettyString(RepositorySet $repositorySet, Request $request, Pool $pool, $isVerbose, array $installedMap = array(), array $learnedPool = array())
+    public function getPrettyString(RepositorySet $repositorySet, Request $request, Pool $pool, bool $isVerbose, array $installedMap = [], array $learnedPool = []): string
     {
         // TODO doesn't this entirely defeat the purpose of the problem sections? what's the point of sections?
-        $reasons = call_user_func_array('array_merge', array_reverse($this->reasons));
+        $reasons = array_merge(...array_reverse($this->reasons));
 
         if (count($reasons) === 1) {
             reset($reasons);
             $rule = current($reasons);
 
-            if (!in_array($rule->getReason(), array(Rule::RULE_ROOT_REQUIRE, Rule::RULE_FIXED), true)) {
-                throw new \LogicException("Single reason problems must contain a request rule.");
+            if ($rule->getReason() !== Rule::RULE_ROOT_REQUIRE) {
+                throw new \LogicException("Single reason problems must contain a root require rule.");
             }
 
             $reasonData = $rule->getReasonData();
             $packageName = $reasonData['packageName'];
             $constraint = $reasonData['constraint'];
 
-            if (isset($constraint)) {
-                $packages = $pool->whatProvides($packageName, $constraint);
-            } else {
-                $packages = array();
-            }
-
-            if (empty($packages)) {
+            $packages = $pool->whatProvides($packageName, $constraint);
+            if (count($packages) === 0) {
                 return "\n    ".implode(self::getMissingPackageReason($repositorySet, $request, $pool, $isVerbose, $packageName, $constraint));
             }
         }
@@ -110,22 +102,20 @@ class Problem
 
     /**
      * @param Rule[] $rules
-     * @param string $indent
-     * @param bool $isVerbose
      * @param array<int|string, BasePackage> $installedMap A map of all present packages
      * @param array<Rule[]> $learnedPool
-     * @return string
      * @internal
      */
-    public static function formatDeduplicatedRules($rules, $indent, RepositorySet $repositorySet, Request $request, Pool $pool, $isVerbose, array $installedMap = array(), array $learnedPool = array())
+    public static function formatDeduplicatedRules(array $rules, string $indent, RepositorySet $repositorySet, Request $request, Pool $pool, bool $isVerbose, array $installedMap = [], array $learnedPool = []): string
     {
-        $messages = array();
-        $templates = array();
+        $messages = [];
+        $templates = [];
         $parser = new VersionParser;
-        $deduplicatableRuleTypes = array(Rule::RULE_PACKAGE_REQUIRES, Rule::RULE_PACKAGE_CONFLICT);
+        $deduplicatableRuleTypes = [Rule::RULE_PACKAGE_REQUIRES, Rule::RULE_PACKAGE_CONFLICT];
         foreach ($rules as $rule) {
             $message = $rule->getPrettyString($repositorySet, $request, $pool, $isVerbose, $installedMap, $learnedPool);
-            if (in_array($rule->getReason(), $deduplicatableRuleTypes, true) && Preg::isMatch('{^(?P<package>\S+) (?P<version>\S+) (?P<type>requires|conflicts)}', $message, $m)) {
+            if (in_array($rule->getReason(), $deduplicatableRuleTypes, true) && Preg::isMatchStrictGroups('{^(?P<package>\S+) (?P<version>\S+) (?P<type>requires|conflicts)}', $message, $m)) {
+                $message = str_replace('%', '%%', $message);
                 $template = Preg::replace('{^\S+ \S+ }', '%s%s ', $message);
                 $messages[] = $template;
                 $templates[$template][$m[1]][$parser->normalize($m[2])] = $m[2];
@@ -138,7 +128,7 @@ class Problem
             }
         }
 
-        $result = array();
+        $result = [];
         foreach (array_unique($messages) as $message) {
             if (isset($templates[$message])) {
                 foreach ($templates[$message] as $package => $versions) {
@@ -162,10 +152,7 @@ class Problem
         return "\n$indent- ".implode("\n$indent- ", $result);
     }
 
-    /**
-     * @return bool
-     */
-    public function isCausedByLock(RepositorySet $repositorySet, Request $request, Pool $pool)
+    public function isCausedByLock(RepositorySet $repositorySet, Request $request, Pool $pool): bool
     {
         foreach ($this->reasons as $sectionRules) {
             foreach ($sectionRules as $rule) {
@@ -183,9 +170,8 @@ class Problem
      *
      * @param string $id     A canonical identifier for the reason
      * @param Rule   $reason The reason descriptor
-     * @return void
      */
-    protected function addReason($id, Rule $reason)
+    protected function addReason(string $id, Rule $reason): void
     {
         // TODO: if a rule is part of a problem description in two sections, isn't this going to remove a message
         // that is important to understand the issue?
@@ -196,21 +182,16 @@ class Problem
         }
     }
 
-    /**
-     * @return void
-     */
-    public function nextSection()
+    public function nextSection(): void
     {
         $this->section++;
     }
 
     /**
      * @internal
-     * @param bool $isVerbose
-     * @param string $packageName
      * @return array{0: string, 1: string}
      */
-    public static function getMissingPackageReason(RepositorySet $repositorySet, Request $request, Pool $pool, $isVerbose, $packageName, ConstraintInterface $constraint = null)
+    public static function getMissingPackageReason(RepositorySet $repositorySet, Request $request, Pool $pool, bool $isVerbose, string $packageName, ?ConstraintInterface $constraint = null): array
     {
         if (PlatformRepository::isPlatformPackage($packageName)) {
             // handle php/php-*/hhvm
@@ -220,24 +201,24 @@ class Problem
                 $msg = "- Root composer.json requires ".$packageName.self::constraintToText($constraint).' but ';
 
                 if (defined('HHVM_VERSION') || ($packageName === 'hhvm' && count($pool->whatProvides($packageName)) > 0)) {
-                    return array($msg, 'your HHVM version does not satisfy that requirement.');
+                    return [$msg, 'your HHVM version does not satisfy that requirement.'];
                 }
 
                 if ($packageName === 'hhvm') {
-                    return array($msg, 'HHVM was not detected on this machine, make sure it is in your PATH.');
+                    return [$msg, 'HHVM was not detected on this machine, make sure it is in your PATH.'];
                 }
 
                 if (null === $version) {
-                    return array($msg, 'the '.$packageName.' package is disabled by your platform config. Enable it again with "composer config platform.'.$packageName.' --unset".');
+                    return [$msg, 'the '.$packageName.' package is disabled by your platform config. Enable it again with "composer config platform.'.$packageName.' --unset".'];
                 }
 
-                return array($msg, 'your '.$packageName.' version ('. $version .') does not satisfy that requirement.');
+                return [$msg, 'your '.$packageName.' version ('. $version .') does not satisfy that requirement.'];
             }
 
             // handle php extensions
             if (0 === stripos($packageName, 'ext-')) {
                 if (false !== strpos($packageName, ' ')) {
-                    return array('- ', "PHP extension ".$packageName.' should be required as '.str_replace(' ', '-', $packageName).'.');
+                    return ['- ', "PHP extension ".$packageName.' should be required as '.str_replace(' ', '-', $packageName).'.'];
                 }
 
                 $ext = substr($packageName, 4);
@@ -246,16 +227,16 @@ class Problem
                 $version = self::getPlatformPackageVersion($pool, $packageName, phpversion($ext) ?: '0');
                 if (null === $version) {
                     if (extension_loaded($ext)) {
-                        return array(
+                        return [
                             $msg,
                             'the '.$packageName.' package is disabled by your platform config. Enable it again with "composer config platform.'.$packageName.' --unset".',
-                        );
+                        ];
                     }
 
-                    return array($msg, 'it is missing from your system. Install or enable PHP\'s '.$ext.' extension.');
+                    return [$msg, 'it is missing from your system. Install or enable PHP\'s '.$ext.' extension.'];
                 }
 
-                return array($msg, 'it has the wrong version installed ('.$version.').');
+                return [$msg, 'it has the wrong version installed ('.$version.').'];
             }
 
             // handle linked libs
@@ -263,10 +244,10 @@ class Problem
                 if (strtolower($packageName) === 'lib-icu') {
                     $error = extension_loaded('intl') ? 'it has the wrong version installed, try upgrading the intl extension.' : 'it is missing from your system, make sure the intl extension is loaded.';
 
-                    return array("- Root composer.json requires linked library ".$packageName.self::constraintToText($constraint).' but ', $error);
+                    return ["- Root composer.json requires linked library ".$packageName.self::constraintToText($constraint).' but ', $error];
                 }
 
-                return array("- Root composer.json requires linked library ".$packageName.self::constraintToText($constraint).' but ', 'it has the wrong version installed or is missing from your system, make sure to load the extension providing it.');
+                return ["- Root composer.json requires linked library ".$packageName.self::constraintToText($constraint).' but ', 'it has the wrong version installed or is missing from your system, make sure to load the extension providing it.'];
             }
         }
 
@@ -275,7 +256,7 @@ class Problem
             if ($package->getName() === $packageName) {
                 $lockedPackage = $package;
                 if ($pool->isUnacceptableFixedOrLockedPackage($package)) {
-                    return array("- ", $package->getPrettyName().' is fixed to '.$package->getPrettyVersion().' (lock file version) by a partial update but that version is rejected by your minimum-stability. Make sure you list it as an argument for the update command.');
+                    return ["- ", $package->getPrettyName().' is fixed to '.$package->getPrettyVersion().' (lock file version) by a partial update but that version is rejected by your minimum-stability. Make sure you list it as an argument for the update command.'];
                 }
                 break;
             }
@@ -286,33 +267,43 @@ class Problem
         if ($packages = $repositorySet->findPackages($packageName, $constraint)) {
             $rootReqs = $repositorySet->getRootRequires();
             if (isset($rootReqs[$packageName])) {
-                $filtered = array_filter($packages, function ($p) use ($rootReqs, $packageName) {
+                $filtered = array_filter($packages, static function ($p) use ($rootReqs, $packageName): bool {
                     return $rootReqs[$packageName]->matches(new Constraint('==', $p->getVersion()));
                 });
                 if (0 === count($filtered)) {
-                    return array("- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ', 'found '.self::getPackageList($packages, $isVerbose, $pool, $constraint).' but '.(self::hasMultipleNames($packages) ? 'these conflict' : 'it conflicts').' with your root composer.json require ('.$rootReqs[$packageName]->getPrettyString().').');
+                    return ["- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ', 'found '.self::getPackageList($packages, $isVerbose, $pool, $constraint).' but '.(self::hasMultipleNames($packages) ? 'these conflict' : 'it conflicts').' with your root composer.json require ('.$rootReqs[$packageName]->getPrettyString().').'];
+                }
+            }
+
+            $tempReqs = $repositorySet->getTemporaryConstraints();
+            if (isset($tempReqs[$packageName])) {
+                $filtered = array_filter($packages, static function ($p) use ($tempReqs, $packageName): bool {
+                    return $tempReqs[$packageName]->matches(new Constraint('==', $p->getVersion()));
+                });
+                if (0 === count($filtered)) {
+                    return ["- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ', 'found '.self::getPackageList($packages, $isVerbose, $pool, $constraint).' but '.(self::hasMultipleNames($packages) ? 'these conflict' : 'it conflicts').' with your temporary update constraint ('.$packageName.':'.$tempReqs[$packageName]->getPrettyString().').'];
                 }
             }
 
             if ($lockedPackage) {
                 $fixedConstraint = new Constraint('==', $lockedPackage->getVersion());
-                $filtered = array_filter($packages, function ($p) use ($fixedConstraint) {
+                $filtered = array_filter($packages, static function ($p) use ($fixedConstraint): bool {
                     return $fixedConstraint->matches(new Constraint('==', $p->getVersion()));
                 });
                 if (0 === count($filtered)) {
-                    return array("- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ', 'found '.self::getPackageList($packages, $isVerbose, $pool, $constraint).' but the package is fixed to '.$lockedPackage->getPrettyVersion().' (lock file version) by a partial update and that version does not match. Make sure you list it as an argument for the update command.');
+                    return ["- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ', 'found '.self::getPackageList($packages, $isVerbose, $pool, $constraint).' but the package is fixed to '.$lockedPackage->getPrettyVersion().' (lock file version) by a partial update and that version does not match. Make sure you list it as an argument for the update command.'];
                 }
             }
 
-            $nonLockedPackages = array_filter($packages, function ($p) {
+            $nonLockedPackages = array_filter($packages, static function ($p): bool {
                 return !$p->getRepository() instanceof LockArrayRepository;
             });
 
             if (!$nonLockedPackages) {
-                return array("- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ', 'found '.self::getPackageList($packages, $isVerbose, $pool, $constraint).' in the lock file but not in remote repositories, make sure you avoid updating this package to keep the one from the lock file.');
+                return ["- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ', 'found '.self::getPackageList($packages, $isVerbose, $pool, $constraint).' in the lock file but not in remote repositories, make sure you avoid updating this package to keep the one from the lock file.'];
             }
 
-            return array("- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ', 'found '.self::getPackageList($packages, $isVerbose, $pool, $constraint).' but these were not loaded, likely because '.(self::hasMultipleNames($packages) ? 'they conflict' : 'it conflicts').' with another require.');
+            return ["- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ', 'found '.self::getPackageList($packages, $isVerbose, $pool, $constraint).' but these were not loaded, likely because '.(self::hasMultipleNames($packages) ? 'they conflict' : 'it conflicts').' with another require.'];
         }
 
         // check if the package is found when bypassing stability checks
@@ -322,7 +313,7 @@ class Problem
                 return self::computeCheckForLowerPrioRepo($pool, $isVerbose, $packageName, $packages, $allReposPackages, 'minimum-stability', $constraint);
             }
 
-            return array("- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ', 'found '.self::getPackageList($packages, $isVerbose, $pool, $constraint).' but '.(self::hasMultipleNames($packages) ? 'these do' : 'it does').' not match your minimum-stability.');
+            return ["- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ', 'found '.self::getPackageList($packages, $isVerbose, $pool, $constraint).' but '.(self::hasMultipleNames($packages) ? 'these do' : 'it does').' not match your minimum-stability.'];
         }
 
         // check if the package is found when bypassing the constraint and stability checks
@@ -335,7 +326,7 @@ class Problem
             $suffix = '';
             if ($constraint instanceof Constraint && $constraint->getVersion() === 'dev-master') {
                 foreach ($packages as $candidate) {
-                    if (in_array($candidate->getVersion(), array('dev-default', 'dev-main'), true)) {
+                    if (in_array($candidate->getVersion(), ['dev-default', 'dev-main'], true)) {
                         $suffix = ' Perhaps dev-master was renamed to '.$candidate->getPrettyVersion().'?';
                         break;
                     }
@@ -349,43 +340,40 @@ class Problem
                 $suffix = ' See https://getcomposer.org/dep-on-root for details and assistance.';
             }
 
-            return array("- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ', 'found '.self::getPackageList($packages, $isVerbose, $pool, $constraint).' but '.(self::hasMultipleNames($packages) ? 'these do' : 'it does').' not match the constraint.' . $suffix);
+            return ["- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ', 'found '.self::getPackageList($packages, $isVerbose, $pool, $constraint).' but '.(self::hasMultipleNames($packages) ? 'these do' : 'it does').' not match the constraint.' . $suffix];
         }
 
         if (!Preg::isMatch('{^[A-Za-z0-9_./-]+$}', $packageName)) {
             $illegalChars = Preg::replace('{[A-Za-z0-9_./-]+}', '', $packageName);
 
-            return array("- Root composer.json requires $packageName, it ", 'could not be found, it looks like its name is invalid, "'.$illegalChars.'" is not allowed in package names.');
+            return ["- Root composer.json requires $packageName, it ", 'could not be found, it looks like its name is invalid, "'.$illegalChars.'" is not allowed in package names.'];
         }
 
         if ($providers = $repositorySet->getProviders($packageName)) {
             $maxProviders = 20;
-            $providersStr = implode(array_map(function ($p) {
+            $providersStr = implode(array_map(static function ($p): string {
                 $description = $p['description'] ? ' '.substr($p['description'], 0, 100) : '';
 
-                return "      - ${p['name']}".$description."\n";
+                return '      - '.$p['name'].$description."\n";
             }, count($providers) > $maxProviders + 1 ? array_slice($providers, 0, $maxProviders) : $providers));
             if (count($providers) > $maxProviders + 1) {
                 $providersStr .= '      ... and '.(count($providers) - $maxProviders).' more.'."\n";
             }
 
-            return array("- Root composer.json requires $packageName".self::constraintToText($constraint).", it ", "could not be found in any version, but the following packages provide it:\n".$providersStr."      Consider requiring one of these to satisfy the $packageName requirement.");
+            return ["- Root composer.json requires $packageName".self::constraintToText($constraint).", it ", "could not be found in any version, but the following packages provide it:\n".$providersStr."      Consider requiring one of these to satisfy the $packageName requirement."];
         }
 
-        return array("- Root composer.json requires $packageName, it ", "could not be found in any version, there may be a typo in the package name.");
+        return ["- Root composer.json requires $packageName, it ", "could not be found in any version, there may be a typo in the package name."];
     }
 
     /**
      * @internal
      * @param PackageInterface[] $packages
-     * @param bool $isVerbose
-     * @param bool $useRemovedVersionGroup
-     * @return string
      */
-    public static function getPackageList(array $packages, $isVerbose, Pool $pool = null, ConstraintInterface $constraint = null, $useRemovedVersionGroup = false)
+    public static function getPackageList(array $packages, bool $isVerbose, ?Pool $pool = null, ?ConstraintInterface $constraint = null, bool $useRemovedVersionGroup = false): string
     {
-        $prepared = array();
-        $hasDefaultBranch = array();
+        $prepared = [];
+        $hasDefaultBranch = [];
         foreach ($packages as $package) {
             $prepared[$package->getName()]['name'] = $package->getPrettyName();
             $prepared[$package->getName()]['versions'][$package->getVersion()] = $package->getPrettyVersion().($package instanceof AliasPackage ? ' (alias of '.$package->getAliasOf()->getPrettyVersion().')' : '');
@@ -404,7 +392,7 @@ class Problem
             }
         }
 
-        $preparedStrings = array();
+        $preparedStrings = [];
         foreach ($prepared as $name => $package) {
             // remove the implicit default branch alias to avoid cruft in the display
             if (isset($package['versions'][VersionParser::DEFAULT_BRANCH_ALIAS], $hasDefaultBranch[$name])) {
@@ -423,11 +411,10 @@ class Problem
     }
 
     /**
-     * @param  string $packageName
      * @param  string $version the effective runtime version of the platform package
      * @return ?string a version string or null if it appears the package was artificially disabled
      */
-    private static function getPlatformPackageVersion(Pool $pool, $packageName, $version)
+    private static function getPlatformPackageVersion(Pool $pool, string $packageName, string $version): ?string
     {
         $available = $pool->whatProvides($packageName);
 
@@ -466,19 +453,17 @@ class Problem
     }
 
     /**
-     * @param string[] $versions an array of pretty versions, with normalized versions as keys
-     * @param int $max
-     * @param int $maxDev
+     * @param array<string, string> $versions an array of pretty versions, with normalized versions as keys
      * @return list<string> a list of pretty versions and '...' where versions were removed
      */
-    private static function condenseVersionList(array $versions, $max, $maxDev = 16)
+    private static function condenseVersionList(array $versions, int $max, int $maxDev = 16): array
     {
         if (count($versions) <= $max) {
-            return $versions;
+            return array_values($versions);
         }
 
-        $filtered = array();
-        $byMajor = array();
+        $filtered = [];
+        $byMajor = [];
         foreach ($versions as $version => $pretty) {
             if (0 === stripos($version, 'dev-')) {
                 $byMajor['dev'][] = $pretty;
@@ -503,9 +488,8 @@ class Problem
 
     /**
      * @param PackageInterface[] $packages
-     * @return bool
      */
-    private static function hasMultipleNames(array $packages)
+    private static function hasMultipleNames(array $packages): bool
     {
         $name = null;
         foreach ($packages as $package) {
@@ -520,16 +504,13 @@ class Problem
     }
 
     /**
-     * @param bool $isVerbose
-     * @param string $packageName
      * @param PackageInterface[] $higherRepoPackages
      * @param PackageInterface[] $allReposPackages
-     * @param string $reason
      * @return array{0: string, 1: string}
      */
-    private static function computeCheckForLowerPrioRepo(Pool $pool, $isVerbose, $packageName, array $higherRepoPackages, array $allReposPackages, $reason, ConstraintInterface $constraint = null)
+    private static function computeCheckForLowerPrioRepo(Pool $pool, bool $isVerbose, string $packageName, array $higherRepoPackages, array $allReposPackages, string $reason, ?ConstraintInterface $constraint = null): array
     {
-        $nextRepoPackages = array();
+        $nextRepoPackages = [];
         $nextRepo = null;
 
         foreach ($allReposPackages as $package) {
@@ -544,10 +525,10 @@ class Problem
         if ($higherRepoPackages) {
             $topPackage = reset($higherRepoPackages);
             if ($topPackage instanceof RootPackageInterface) {
-                return array(
+                return [
                     "- Root composer.json requires $packageName".self::constraintToText($constraint).', it is ',
                     'satisfiable by '.self::getPackageList($nextRepoPackages, $isVerbose, $pool, $constraint).' from '.$nextRepo->getRepoName().' but '.$topPackage->getPrettyName().' is the root package and cannot be modified. See https://getcomposer.org/dep-on-root for details and assistance.',
-                );
+                ];
             }
         }
 
@@ -563,20 +544,18 @@ class Problem
                 }
             }
 
-            return array("- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ',
+            return ["- Root composer.json requires $packageName".self::constraintToText($constraint) . ', ',
                 'found ' . self::getPackageList($higherRepoPackages, $isVerbose, $pool, $constraint).' but ' . ($singular ? 'it does' : 'these do') . ' not match your '.$reason.' and ' . ($singular ? 'is' : 'are') . ' therefore not installable. '.$suggestion,
-            );
+            ];
         }
 
-        return array("- Root composer.json requires $packageName".self::constraintToText($constraint) . ', it is ', 'satisfiable by '.self::getPackageList($nextRepoPackages, $isVerbose, $pool, $constraint).' from '.$nextRepo->getRepoName().' but '.self::getPackageList($higherRepoPackages, $isVerbose, $pool, $constraint).' from '.reset($higherRepoPackages)->getRepository()->getRepoName().' has higher repository priority. The packages from the higher priority repository do not match your '.$reason.' and are therefore not installable. That repository is canonical so the lower priority repo\'s packages are not installable. See https://getcomposer.org/repoprio for details and assistance.');
+        return ["- Root composer.json requires $packageName".self::constraintToText($constraint) . ', it is ', 'satisfiable by '.self::getPackageList($nextRepoPackages, $isVerbose, $pool, $constraint).' from '.$nextRepo->getRepoName().' but '.self::getPackageList($higherRepoPackages, $isVerbose, $pool, $constraint).' from '.reset($higherRepoPackages)->getRepository()->getRepoName().' has higher repository priority. The packages from the higher priority repository do not match your '.$reason.' and are therefore not installable. That repository is canonical so the lower priority repo\'s packages are not installable. See https://getcomposer.org/repoprio for details and assistance.'];
     }
 
     /**
      * Turns a constraint into text usable in a sentence describing a request
-     *
-     * @return string
      */
-    protected static function constraintToText(ConstraintInterface $constraint = null)
+    protected static function constraintToText(?ConstraintInterface $constraint = null): string
     {
         return $constraint ? ' '.$constraint->getPrettyString() : '';
     }
