@@ -21,10 +21,10 @@ use Composer\Repository\PlatformRepository;
 class JsonManipulator
 {
     /** @var string */
-    private static $DEFINES = '(?(DEFINE)
-       (?<number>    -? (?= [1-9]|0(?!\d) ) \d++ (\.\d++)? ([eE] [+-]?+ \d++)? )
+    private const DEFINES = '(?(DEFINE)
+       (?<number>    -? (?= [1-9]|0(?!\d) ) \d++ (?:\.\d++)? (?:[eE] [+-]?+ \d++)? )
        (?<boolean>   true | false | null )
-       (?<string>    " ([^"\\\\]*+ | \\\\ ["\\\\bfnrt\/] | \\\\ u [0-9A-Fa-f]{4} )* " )
+       (?<string>    " (?:[^"\\\\]*+ | \\\\ ["\\\\bfnrt\/] | \\\\ u [0-9A-Fa-f]{4} )* " )
        (?<array>     \[  (?:  (?&json) \s*+ (?: , (?&json) \s*+ )*+  )?+  \s*+ \] )
        (?<pair>      \s*+ (?&string) \s*+ : (?&json) \s*+ )
        (?<object>    \{  (?:  (?&pair)  (?: , (?&pair)  )*+  )?+  \s*+ \} )
@@ -66,26 +66,30 @@ class JsonManipulator
             return $this->addMainKey($type, [$package => $constraint]);
         }
 
-        $regex = '{'.self::$DEFINES.'^(?P<start>\s*\{\s*(?:(?&string)\s*:\s*(?&json)\s*,\s*)*?)'.
+        $regex = '{'.self::DEFINES.'^(?P<start>\s*\{\s*(?:(?&string)\s*:\s*(?&json)\s*,\s*)*?)'.
             '(?P<property>'.preg_quote(JsonFile::encode($type)).'\s*:\s*)(?P<value>(?&json))(?P<end>.*)}sx';
         if (!Preg::isMatch($regex, $this->contents, $matches)) {
             return false;
         }
+        assert(is_string($matches['start']));
+        assert(is_string($matches['value']));
+        assert(is_string($matches['end']));
 
         $links = $matches['value'];
 
         // try to find existing link
         $packageRegex = str_replace('/', '\\\\?/', preg_quote($package));
-        $regex = '{'.self::$DEFINES.'"(?P<package>'.$packageRegex.')"(\s*:\s*)(?&string)}ix';
+        $regex = '{'.self::DEFINES.'"(?P<package>'.$packageRegex.')"(\s*:\s*)(?&string)}ix';
         if (Preg::isMatch($regex, $links, $packageMatches)) {
+            assert(is_string($packageMatches['package']));
             // update existing link
             $existingPackage = $packageMatches['package'];
             $packageRegex = str_replace('/', '\\\\?/', preg_quote($existingPackage));
-            $links = Preg::replaceCallback('{'.self::$DEFINES.'"'.$packageRegex.'"(?P<separator>\s*:\s*)(?&string)}ix', static function ($m) use ($existingPackage, $constraint): string {
+            $links = Preg::replaceCallback('{'.self::DEFINES.'"'.$packageRegex.'"(?P<separator>\s*:\s*)(?&string)}ix', static function ($m) use ($existingPackage, $constraint): string {
                 return JsonFile::encode(str_replace('\\/', '/', $existingPackage)) . $m['separator'] . '"' . $constraint . '"';
             }, $links);
         } else {
-            if (Preg::isMatch('#^\s*\{\s*\S+.*?(\s*\}\s*)$#s', $links, $match)) {
+            if (Preg::isMatchStrictGroups('#^\s*\{\s*\S+.*?(\s*\}\s*)$#s', $links, $match)) {
                 // link missing but non empty links
                 $links = Preg::replace(
                     '{'.preg_quote($match[1]).'$}',
@@ -237,7 +241,7 @@ class JsonManipulator
         }
 
         // main node content not match-able
-        $nodeRegex = '{'.self::$DEFINES.'^(?P<start> \s* \{ \s* (?: (?&string) \s* : (?&json) \s* , \s* )*?'.
+        $nodeRegex = '{'.self::DEFINES.'^(?P<start> \s* \{ \s* (?: (?&string) \s* : (?&json) \s* , \s* )*?'.
             preg_quote(JsonFile::encode($mainNode)).'\s*:\s*)(?P<content>(?&object))(?P<end>.*)}sx';
 
         try {
@@ -251,6 +255,10 @@ class JsonManipulator
             throw $e;
         }
 
+        assert(is_string($match['start']));
+        assert(is_string($match['content']));
+        assert(is_string($match['end']));
+
         $children = $match['content'];
         // invalid match due to un-regexable content, abort
         if (!@json_decode($children)) {
@@ -258,10 +266,10 @@ class JsonManipulator
         }
 
         // child exists
-        $childRegex = '{'.self::$DEFINES.'(?P<start>"'.preg_quote($name).'"\s*:\s*)(?P<content>(?&json))(?P<end>,?)}x';
+        $childRegex = '{'.self::DEFINES.'(?P<start>"'.preg_quote($name).'"\s*:\s*)(?P<content>(?&json))(?P<end>,?)}x';
         if (Preg::isMatch($childRegex, $children, $matches)) {
             $children = Preg::replaceCallback($childRegex, function ($matches) use ($subName, $value): string {
-                if ($subName !== null) {
+                if ($subName !== null && is_string($matches['content'])) {
                     $curVal = json_decode($matches['content'], true);
                     if (!is_array($curVal)) {
                         $curVal = [];
@@ -331,7 +339,7 @@ class JsonManipulator
         }
 
         // no node content match-able
-        $nodeRegex = '{'.self::$DEFINES.'^(?P<start> \s* \{ \s* (?: (?&string) \s* : (?&json) \s* , \s* )*?'.
+        $nodeRegex = '{'.self::DEFINES.'^(?P<start> \s* \{ \s* (?: (?&string) \s* : (?&json) \s* , \s* )*?'.
             preg_quote(JsonFile::encode($mainNode)).'\s*:\s*)(?P<content>(?&object))(?P<end>.*)}sx';
         try {
             if (!Preg::isMatch($nodeRegex, $this->contents, $match)) {
@@ -344,6 +352,10 @@ class JsonManipulator
             throw $e;
         }
 
+        assert(is_string($match['start']));
+        assert(is_string($match['content']));
+        assert(is_string($match['end']));
+
         $children = $match['content'];
 
         // invalid match due to un-regexable content, abort
@@ -365,9 +377,10 @@ class JsonManipulator
         $keyRegex = str_replace('/', '\\\\?/', preg_quote($name));
         if (Preg::isMatch('{"'.$keyRegex.'"\s*:}i', $children)) {
             // find best match for the value of "name"
-            if (Preg::isMatchAll('{'.self::$DEFINES.'"'.$keyRegex.'"\s*:\s*(?:(?&json))}x', $children, $matches)) {
+            if (Preg::isMatchAll('{'.self::DEFINES.'"'.$keyRegex.'"\s*:\s*(?:(?&json))}x', $children, $matches)) {
                 $bestMatch = '';
                 foreach ($matches[0] as $match) {
+                    assert(is_string($match));
                     if (strlen($bestMatch) < strlen($match)) {
                         $bestMatch = $match;
                     }
@@ -410,6 +423,7 @@ class JsonManipulator
         }
 
         $this->contents = Preg::replaceCallback($nodeRegex, function ($matches) use ($name, $subName, $childrenClean): string {
+            assert(is_string($matches['content']));
             if ($subName !== null) {
                 $curVal = json_decode($matches['content'], true);
                 unset($curVal[$name][$subName]);
@@ -431,7 +445,7 @@ class JsonManipulator
         $content = $this->format($content);
 
         // key exists already
-        $regex = '{'.self::$DEFINES.'^(?P<start>\s*\{\s*(?:(?&string)\s*:\s*(?&json)\s*,\s*)*?)'.
+        $regex = '{'.self::DEFINES.'^(?P<start>\s*\{\s*(?:(?&string)\s*:\s*(?&json)\s*,\s*)*?)'.
             '(?P<key>'.preg_quote(JsonFile::encode($key)).'\s*:\s*(?&json))(?P<end>.*)}sx';
         if (isset($decoded[$key]) && Preg::isMatch($regex, $this->contents, $matches)) {
             // invalid match due to un-regexable content, abort
@@ -474,16 +488,20 @@ class JsonManipulator
         }
 
         // key exists already
-        $regex = '{'.self::$DEFINES.'^(?P<start>\s*\{\s*(?:(?&string)\s*:\s*(?&json)\s*,\s*)*?)'.
+        $regex = '{'.self::DEFINES.'^(?P<start>\s*\{\s*(?:(?&string)\s*:\s*(?&json)\s*,\s*)*?)'.
             '(?P<removal>'.preg_quote(JsonFile::encode($key)).'\s*:\s*(?&json))\s*,?\s*(?P<end>.*)}sx';
         if (Preg::isMatch($regex, $this->contents, $matches)) {
+            assert(is_string($matches['start']));
+            assert(is_string($matches['removal']));
+            assert(is_string($matches['end']));
+
             // invalid match due to un-regexable content, abort
             if (!@json_decode('{'.$matches['removal'].'}')) {
                 return false;
             }
 
             // check that we are not leaving a dangling comma on the previous line if the last line was removed
-            if (Preg::isMatch('#,\s*$#', $matches['start']) && Preg::isMatch('#^\}$#', $matches['end'])) {
+            if (Preg::isMatchStrictGroups('#,\s*$#', $matches['start']) && Preg::isMatch('#^\}$#', $matches['end'])) {
                 $matches['start'] = rtrim(Preg::replace('#,(\s*)$#', '$1', $matches['start']), $this->indent);
             }
 
@@ -543,7 +561,7 @@ class JsonManipulator
 
     protected function detectIndenting(): void
     {
-        if (Preg::isMatch('{^([ \t]+)"}m', $this->contents, $match)) {
+        if (Preg::isMatchStrictGroups('{^([ \t]+)"}m', $this->contents, $match)) {
             $this->indent = $match[1];
         } else {
             $this->indent = '    ';
