@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -15,6 +15,7 @@ namespace Composer\Package\Version;
 use Composer\Filter\PlatformRequirementFilter\IgnoreAllPlatformRequirementFilter;
 use Composer\Filter\PlatformRequirementFilter\PlatformRequirementFilterFactory;
 use Composer\Filter\PlatformRequirementFilter\PlatformRequirementFilterInterface;
+use Composer\IO\IOInterface;
 use Composer\Package\BasePackage;
 use Composer\Package\AliasPackage;
 use Composer\Package\PackageInterface;
@@ -39,7 +40,7 @@ class VersionSelector
     private $repositorySet;
 
     /** @var array<string, ConstraintInterface[]> */
-    private $platformConstraints = array();
+    private $platformConstraints = [];
 
     /** @var VersionParser */
     private $parser;
@@ -47,7 +48,7 @@ class VersionSelector
     /**
      * @param PlatformRepository $platformRepo If passed in, the versions found will be filtered against their requirements to eliminate any not matching the current platform packages
      */
-    public function __construct(RepositorySet $repositorySet, PlatformRepository $platformRepo = null)
+    public function __construct(RepositorySet $repositorySet, ?PlatformRepository $platformRepo = null)
     {
         $this->repositorySet = $repositorySet;
         if ($platformRepo) {
@@ -61,14 +62,13 @@ class VersionSelector
      * Given a package name and optional version, returns the latest PackageInterface
      * that matches.
      *
-     * @param string                                           $packageName
      * @param string                                           $targetPackageVersion
-     * @param string                                           $preferredStability
      * @param PlatformRequirementFilterInterface|bool|string[] $platformRequirementFilter
-     * @param int                                              $repoSetFlags*
+     * @param IOInterface|null                                 $io                        If passed, warnings will be output there in case versions cannot be selected due to platform requirements
+     * @param callable(PackageInterface):bool|bool             $showWarnings
      * @return PackageInterface|false
      */
-    public function findBestCandidate($packageName, $targetPackageVersion = null, $preferredStability = 'stable', $platformRequirementFilter = null, $repoSetFlags = 0)
+    public function findBestCandidate(string $packageName, ?string $targetPackageVersion = null, string $preferredStability = 'stable', $platformRequirementFilter = null, int $repoSetFlags = 0, ?IOInterface $io = null, $showWarnings = true)
     {
         if (!isset(BasePackage::$stabilities[$preferredStability])) {
             // If you get this, maybe you are still relying on the Composer 1.x signature where the 3rd arg was the php version
@@ -85,68 +85,87 @@ class VersionSelector
         $constraint = $targetPackageVersion ? $this->getParser()->parseConstraints($targetPackageVersion) : null;
         $candidates = $this->repositorySet->findPackages(strtolower($packageName), $constraint, $repoSetFlags);
 
-        if ($this->platformConstraints && !($platformRequirementFilter instanceof IgnoreAllPlatformRequirementFilter)) {
-            $platformConstraints = $this->platformConstraints;
-            $candidates = array_filter($candidates, function ($pkg) use ($platformConstraints, $platformRequirementFilter) {
-                $reqs = $pkg->getRequires();
-
-                foreach ($reqs as $name => $link) {
-                    if (!$platformRequirementFilter->isIgnored($name)) {
-                        if (isset($platformConstraints[$name])) {
-                            foreach ($platformConstraints[$name] as $constraint) {
-                                if ($link->getConstraint()->matches($constraint)) {
-                                    continue 2;
-                                }
-                            }
-
-                            return false;
-                        } elseif (PlatformRepository::isPlatformPackage($name)) {
-                            // Package requires a platform package that is unknown on current platform.
-                            // It means that current platform cannot validate this constraint and so package is not installable.
-                            return false;
-                        }
-                    }
-                }
-
-                return true;
-            });
-        }
-
-        if (!$candidates) {
-            return false;
-        }
-
-        // select highest version if we have many
-        $package = reset($candidates);
         $minPriority = BasePackage::$stabilities[$preferredStability];
-        foreach ($candidates as $candidate) {
-            $candidatePriority = $candidate->getStabilityPriority();
-            $currentPriority = $package->getStabilityPriority();
+        usort($candidates, static function (PackageInterface $a, PackageInterface $b) use ($minPriority) {
+            $aPriority = $a->getStabilityPriority();
+            $bPriority = $b->getStabilityPriority();
 
-            // candidate is less stable than our preferred stability,
-            // and current package is more stable than candidate, skip it
-            if ($minPriority < $candidatePriority && $currentPriority < $candidatePriority) {
-                continue;
+            // A is less stable than our preferred stability,
+            // and B is more stable than A, select B
+            if ($minPriority < $aPriority && $bPriority < $aPriority) {
+                return 1;
             }
 
-            // candidate is less stable than our preferred stability,
-            // and current package is less stable than candidate, select candidate
-            if ($minPriority < $candidatePriority && $candidatePriority < $currentPriority) {
-                $package = $candidate;
-                continue;
+            // A is less stable than our preferred stability,
+            // and B is less stable than A, select A
+            if ($minPriority < $aPriority && $aPriority < $bPriority) {
+                return -1;
             }
 
-            // candidate is more stable than our preferred stability,
-            // and current package is less stable than preferred stability, select candidate
-            if ($minPriority >= $candidatePriority && $minPriority < $currentPriority) {
-                $package = $candidate;
-                continue;
+            // A is more stable than our preferred stability,
+            // and B is less stable than preferred stability, select A
+            if ($minPriority >= $aPriority && $minPriority < $bPriority) {
+                return -1;
             }
 
             // select highest version of the two
-            if (version_compare($package->getVersion(), $candidate->getVersion(), '<')) {
-                $package = $candidate;
+            return version_compare($b->getVersion(), $a->getVersion());
+        });
+
+        if (count($this->platformConstraints) > 0 && !($platformRequirementFilter instanceof IgnoreAllPlatformRequirementFilter)) {
+            /** @var array<string, true> $alreadyWarnedNames */
+            $alreadyWarnedNames = [];
+            /** @var array<string, true> $alreadySeenNames */
+            $alreadySeenNames = [];
+
+            foreach ($candidates as $pkg) {
+                $reqs = $pkg->getRequires();
+                foreach ($reqs as $name => $link) {
+                    if (!PlatformRepository::isPlatformPackage($name) || $platformRequirementFilter->isIgnored($name)) {
+                        continue;
+                    }
+                    if (isset($this->platformConstraints[$name])) {
+                        foreach ($this->platformConstraints[$name] as $providedConstraint) {
+                            if ($link->getConstraint()->matches($providedConstraint)) {
+                                // constraint satisfied, go to next require
+                                continue 2;
+                            }
+                        }
+
+                        // constraint not satisfied
+                        $reason = 'is not satisfied by your platform';
+                    } else {
+                        // Package requires a platform package that is unknown on current platform.
+                        // It means that current platform cannot validate this constraint and so package is not installable.
+                        $reason = 'is missing from your platform';
+                    }
+
+                    $isLatestVersion = !isset($alreadySeenNames[$pkg->getName()]);
+                    $alreadySeenNames[$pkg->getName()] = true;
+                    if ($io !== null && ($showWarnings === true || (is_callable($showWarnings) && $showWarnings($pkg)))) {
+                        $isFirstWarning = !isset($alreadyWarnedNames[$pkg->getName()]);
+                        $alreadyWarnedNames[$pkg->getName()] = true;
+                        $latest = $isLatestVersion ? "'s latest version" : '';
+                        $io->writeError(
+                            '<warning>Cannot use '.$pkg->getPrettyName().$latest.' '.$pkg->getPrettyVersion().' as it '.$link->getDescription().' '.$link->getTarget().' '.$link->getPrettyConstraint().' which '.$reason.'.</>',
+                            true,
+                            $isFirstWarning ? IOInterface::NORMAL : IOInterface::VERBOSE
+                        );
+                    }
+
+                    // skip candidate
+                    continue 2;
+                }
+
+                $package = $pkg;
+                break;
             }
+        } else {
+            $package = count($candidates) > 0 ? $candidates[0] : null;
+        }
+
+        if (!isset($package)) {
+            return false;
         }
 
         // if we end up with 9999999-dev as selected package, make sure we use the original version instead of the alias
@@ -168,11 +187,8 @@ class VersionSelector
      *  * 2.0-beta.1    -> ^2.0@beta
      *  * dev-master    -> ^2.1@dev      (dev version with alias)
      *  * dev-master    -> dev-master    (dev versions are untouched)
-     *
-     * @param  PackageInterface $package
-     * @return string
      */
-    public function findRecommendedRequireVersion(PackageInterface $package)
+    public function findRecommendedRequireVersion(PackageInterface $package): string
     {
         // Extensions which are versioned in sync with PHP should rather be required as "*" to simplify
         // the requires and have only one required version to change when bumping the php requirement
@@ -194,7 +210,7 @@ class VersionSelector
         $extra = $loader->getBranchAlias($dumper->dump($package));
         if ($extra && $extra !== VersionParser::DEFAULT_BRANCH_ALIAS) {
             $extra = Preg::replace('{^(\d+\.\d+\.\d+)(\.9999999)-dev$}', '$1.0', $extra, -1, $count);
-            if ($count) {
+            if ($count > 0) {
                 $extra = str_replace('.9999999', '.0', $extra);
 
                 return $this->transformVersion($extra, $extra, 'dev');
@@ -204,21 +220,14 @@ class VersionSelector
         return $package->getPrettyVersion();
     }
 
-    /**
-     * @param string $version
-     * @param string $prettyVersion
-     * @param string $stability
-     *
-     * @return string
-     */
-    private function transformVersion($version, $prettyVersion, $stability)
+    private function transformVersion(string $version, string $prettyVersion, string $stability): string
     {
         // attempt to transform 2.1.1 to 2.1
         // this allows you to upgrade through minor versions
         $semanticVersionParts = explode('.', $version);
 
         // check to see if we have a semver-looking version
-        if (count($semanticVersionParts) == 4 && Preg::isMatch('{^0\D?}', $semanticVersionParts[3])) {
+        if (count($semanticVersionParts) === 4 && Preg::isMatch('{^0\D?}', $semanticVersionParts[3])) {
             // remove the last parts (i.e. the patch version number and any extra)
             if ($semanticVersionParts[0] === '0') {
                 unset($semanticVersionParts[3]);
@@ -231,7 +240,7 @@ class VersionSelector
         }
 
         // append stability flag if not default
-        if ($stability != 'stable') {
+        if ($stability !== 'stable') {
             $version .= '@'.$stability;
         }
 
@@ -239,10 +248,7 @@ class VersionSelector
         return '^' . $version;
     }
 
-    /**
-     * @return VersionParser
-     */
-    private function getParser()
+    private function getParser(): VersionParser
     {
         if ($this->parser === null) {
             $this->parser = new VersionParser();
