@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -25,24 +25,18 @@ class HhvmDetector
     /** @var ?ProcessExecutor */
     private $processExecutor;
 
-    public function __construct(ExecutableFinder $executableFinder = null, ProcessExecutor $processExecutor = null)
+    public function __construct(?ExecutableFinder $executableFinder = null, ?ProcessExecutor $processExecutor = null)
     {
         $this->executableFinder = $executableFinder;
         $this->processExecutor = $processExecutor;
     }
 
-    /**
-     * @return void
-     */
-    public function reset()
+    public function reset(): void
     {
         self::$hhvmVersion = null;
     }
 
-    /**
-     * @return string|null
-     */
-    public function getVersion()
+    public function getVersion(): ?string
     {
         if (null !== self::$hhvmVersion) {
             return self::$hhvmVersion ?: null;
@@ -54,7 +48,7 @@ class HhvmDetector
             $this->executableFinder = $this->executableFinder ?: new ExecutableFinder();
             $hhvmPath = $this->executableFinder->find('hhvm');
             if ($hhvmPath !== null) {
-                $this->processExecutor = $this->processExecutor ?: new ProcessExecutor();
+                $this->processExecutor = $this->processExecutor ?? new ProcessExecutor();
                 $exitCode = $this->processExecutor->execute(
                     ProcessExecutor::escape($hhvmPath).
                     ' --php -d hhvm.jit=0 -r "echo HHVM_VERSION;" 2>/dev/null',
