@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -76,7 +76,7 @@ class PrePoolCreateEvent extends Event
      * @phpstan-param array<string, array<string, array{alias: string, alias_normalized: string}>> $rootAliases
      * @phpstan-param array<string, string> $rootReferences
      */
-    public function __construct($name, array $repositories, Request $request, array $acceptableStabilities, array $stabilityFlags, array $rootAliases, array $rootReferences, array $packages, array $unacceptableFixedPackages)
+    public function __construct(string $name, array $repositories, Request $request, array $acceptableStabilities, array $stabilityFlags, array $rootAliases, array $rootReferences, array $packages, array $unacceptableFixedPackages)
     {
         parent::__construct($name);
 
@@ -93,15 +93,12 @@ class PrePoolCreateEvent extends Event
     /**
      * @return RepositoryInterface[]
      */
-    public function getRepositories()
+    public function getRepositories(): array
     {
         return $this->repositories;
     }
 
-    /**
-     * @return Request
-     */
-    public function getRequest()
+    public function getRequest(): Request
     {
         return $this->request;
     }
@@ -110,7 +107,7 @@ class PrePoolCreateEvent extends Event
      * @return int[] array of stability => BasePackage::STABILITY_* value
      * @phpstan-return array<string, BasePackage::STABILITY_*>
      */
-    public function getAcceptableStabilities()
+    public function getAcceptableStabilities(): array
     {
         return $this->acceptableStabilities;
     }
@@ -119,7 +116,7 @@ class PrePoolCreateEvent extends Event
      * @return int[] array of package name => BasePackage::STABILITY_* value
      * @phpstan-return array<string, BasePackage::STABILITY_*>
      */
-    public function getStabilityFlags()
+    public function getStabilityFlags(): array
     {
         return $this->stabilityFlags;
     }
@@ -128,7 +125,7 @@ class PrePoolCreateEvent extends Event
      * @return array[] of package => version => [alias, alias_normalized]
      * @phpstan-return array<string, array<string, array{alias: string, alias_normalized: string}>>
      */
-    public function getRootAliases()
+    public function getRootAliases(): array
     {
         return $this->rootAliases;
     }
@@ -137,7 +134,7 @@ class PrePoolCreateEvent extends Event
      * @return string[]
      * @phpstan-return array<string, string>
      */
-    public function getRootReferences()
+    public function getRootReferences(): array
     {
         return $this->rootReferences;
     }
@@ -145,7 +142,7 @@ class PrePoolCreateEvent extends Event
     /**
      * @return BasePackage[]
      */
-    public function getPackages()
+    public function getPackages(): array
     {
         return $this->packages;
     }
@@ -153,27 +150,23 @@ class PrePoolCreateEvent extends Event
     /**
      * @return BasePackage[]
      */
-    public function getUnacceptableFixedPackages()
+    public function getUnacceptableFixedPackages(): array
     {
         return $this->unacceptableFixedPackages;
     }
 
     /**
      * @param BasePackage[] $packages
-     *
-     * @return void
      */
-    public function setPackages(array $packages)
+    public function setPackages(array $packages): void
     {
         $this->packages = $packages;
     }
 
     /**
      * @param BasePackage[] $packages
-     *
-     * @return void
      */
-    public function setUnacceptableFixedPackages(array $packages)
+    public function setUnacceptableFixedPackages(array $packages): void
     {
         $this->unacceptableFixedPackages = $packages;
     }
