@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -21,7 +21,9 @@ namespace Composer\Repository;
  */
 class LockArrayRepository extends ArrayRepository
 {
-    public function getRepoName()
+    use CanonicalPackagesTrait;
+
+    public function getRepoName(): string
     {
         return 'lock repo';
     }
