@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -13,14 +13,14 @@
 namespace Composer\Repository;
 
 use Composer\Config;
+use Composer\EventDispatcher\EventDispatcher;
 use Composer\IO\IOInterface;
 use Composer\Json\JsonFile;
-use Composer\Package\CompleteAliasPackage;
-use Composer\Package\CompletePackage;
 use Composer\Package\Loader\ArrayLoader;
 use Composer\Package\Version\VersionGuesser;
 use Composer\Package\Version\VersionParser;
 use Composer\Pcre\Preg;
+use Composer\Util\HttpDownloader;
 use Composer\Util\Platform;
 use Composer\Util\ProcessExecutor;
 use Composer\Util\Filesystem;
@@ -56,6 +56,13 @@ use Composer\Util\Git as GitUtil;
  *             "symlink": false
  *         }
  *     },
+ *     {
+ *         "type": "path",
+ *         "url": "../../relative/path/to/package/",
+ *         "options": {
+ *             "reference": "none"
+ *         }
+ *     },
  * ]
  * @endcode
  *
@@ -81,7 +88,7 @@ class PathRepository extends ArrayRepository implements ConfigurableRepositoryIn
 
     /**
      * @var mixed[]
-     * @phpstan-var array{url: string, options?: array{symlink?: bool, relative?: bool, versions?: array<string, string>}}
+     * @phpstan-var array{url: string, options?: array{symlink?: bool, reference?: string, relative?: bool, versions?: array<string, string>}}
      */
     private $repoConfig;
 
@@ -91,18 +98,16 @@ class PathRepository extends ArrayRepository implements ConfigurableRepositoryIn
     private $process;
 
     /**
-     * @var array{symlink?: bool, relative?: bool, versions?: array<string, string>}
+     * @var array{symlink?: bool, reference?: string, relative?: bool, versions?: array<string, string>}
      */
     private $options;
 
     /**
      * Initializes path repository.
      *
-     * @param array{url?: string, options?: array{symlink?: bool, relative?: bool, versions?: array<string, string>}} $repoConfig
-     * @param IOInterface $io
-     * @param Config      $config
+     * @param array{url?: string, options?: array{symlink?: bool, reference?: string, relative?: bool, versions?: array<string, string>}} $repoConfig
      */
-    public function __construct(array $repoConfig, IOInterface $io, Config $config)
+    public function __construct(array $repoConfig, IOInterface $io, Config $config, ?HttpDownloader $httpDownloader = null, ?EventDispatcher $dispatcher = null, ?ProcessExecutor $process = null)
     {
         if (!isset($repoConfig['url'])) {
             throw new \RuntimeException('You must specify the `url` configuration for the path repository');
@@ -110,10 +115,10 @@ class PathRepository extends ArrayRepository implements ConfigurableRepositoryIn
 
         $this->loader = new ArrayLoader(null, true);
         $this->url = Platform::expandPath($repoConfig['url']);
-        $this->process = new ProcessExecutor($io);
+        $this->process = $process ?? new ProcessExecutor($io);
         $this->versionGuesser = new VersionGuesser($config, $this->process, new VersionParser());
         $this->repoConfig = $repoConfig;
-        $this->options = isset($repoConfig['options']) ? $repoConfig['options'] : array();
+        $this->options = $repoConfig['options'] ?? [];
         if (!isset($this->options['relative'])) {
             $filesystem = new Filesystem();
             $this->options['relative'] = !$filesystem->isAbsolutePath($this->url);
@@ -122,12 +127,12 @@ class PathRepository extends ArrayRepository implements ConfigurableRepositoryIn
         parent::__construct();
     }
 
-    public function getRepoName()
+    public function getRepoName(): string
     {
         return 'path repo ('.Url::sanitize($this->repoConfig['url']).')';
     }
 
-    public function getRepoConfig()
+    public function getRepoConfig(): array
     {
         return $this->repoConfig;
     }
@@ -137,7 +142,7 @@ class PathRepository extends ArrayRepository implements ConfigurableRepositoryIn
      *
      * This method will basically read the folder and add the found package.
      */
-    protected function initialize()
+    protected function initialize(): void
     {
         parent::initialize();
 
@@ -168,15 +173,19 @@ class PathRepository extends ArrayRepository implements ConfigurableRepositoryIn
 
             $json = file_get_contents($composerFilePath);
             $package = JsonFile::parseJson($json, $composerFilePath);
-            $package['dist'] = array(
+            $package['dist'] = [
                 'type' => 'path',
                 'url' => $url,
-                'reference' => sha1($json . serialize($this->options)),
-            );
+            ];
+            $reference = $this->options['reference'] ?? 'auto';
+            if ('none' === $reference) {
+                $package['dist']['reference'] = null;
+            } elseif ('config' === $reference || 'auto' === $reference) {
+                $package['dist']['reference'] = sha1($json . serialize($this->options));
+            }
 
             // copy symlink/relative options to transport options
-            $package['transport-options'] = array_intersect_key($this->options, array('symlink' => true, 'relative' => true));
-
+            $package['transport-options'] = array_intersect_key($this->options, ['symlink' => true, 'relative' => true]);
             // use the version provided as option if available
             if (isset($package['name'], $this->options['versions'][$package['name']])) {
                 $package['version'] = $this->options['versions'][$package['name']];
@@ -194,11 +203,10 @@ class PathRepository extends ArrayRepository implements ConfigurableRepositoryIn
             }
 
             $output = '';
-            if (is_dir($path . DIRECTORY_SEPARATOR . '.git') && 0 === $this->process->execute('git log -n1 --pretty=%H'.GitUtil::getNoShowSignatureFlag($this->process), $output, $path)) {
+            if ('auto' === $reference && is_dir($path . DIRECTORY_SEPARATOR . '.git') && 0 === $this->process->execute('git log -n1 --pretty=%H'.GitUtil::getNoShowSignatureFlag($this->process), $output, $path)) {
                 $package['dist']['reference'] = trim($output);
             }
 
-            $needsAlias = false;
             if (!isset($package['version'])) {
                 $versionData = $this->versionGuesser->guessVersion($package, $path);
                 if (is_array($versionData) && $versionData['pretty_version']) {
@@ -211,16 +219,14 @@ class PathRepository extends ArrayRepository implements ConfigurableRepositoryIn
                     $package['version'] = $versionData['pretty_version'];
                 } else {
                     $package['version'] = 'dev-main';
-                    $needsAlias = true;
                 }
             }
 
-            $package = $this->loader->load($package);
-            if ($needsAlias && $package instanceof CompletePackage) {
-                // keep a dev-master alias to dev-main for BC
-                $package = new CompleteAliasPackage($package, 'dev-master', 'dev-master');
+            try {
+                $this->addPackage($this->loader->load($package));
+            } catch (\Exception $e) {
+                throw new \RuntimeException('Failed loading the package in '.$composerFilePath, 0, $e);
             }
-            $this->addPackage($package);
         }
     }
 
@@ -229,7 +235,7 @@ class PathRepository extends ArrayRepository implements ConfigurableRepositoryIn
      *
      * @return string[]
      */
-    private function getUrlMatches()
+    private function getUrlMatches(): array
     {
         $flags = GLOB_MARK | GLOB_ONLYDIR;
 
@@ -240,7 +246,7 @@ class PathRepository extends ArrayRepository implements ConfigurableRepositoryIn
         }
 
         // Ensure environment-specific path separators are normalized to URL separators
-        return array_map(function ($val) {
+        return array_map(static function ($val): string {
             return rtrim(str_replace(DIRECTORY_SEPARATOR, '/', $val), '/');
         }, glob($this->url, $flags));
     }
