@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -44,8 +44,8 @@ abstract class VcsDriver implements VcsDriverInterface
     protected $process;
     /** @var HttpDownloader */
     protected $httpDownloader;
-    /** @var array<string, mixed> */
-    protected $infoCache = array();
+    /** @var array<int|string, mixed> */
+    protected $infoCache = [];
     /** @var ?Cache */
     protected $cache;
 
@@ -75,11 +75,8 @@ abstract class VcsDriver implements VcsDriverInterface
 
     /**
      * Returns whether or not the given $identifier should be cached or not.
-     *
-     * @param  string $identifier
-     * @return bool
      */
-    protected function shouldCache($identifier)
+    protected function shouldCache(string $identifier): bool
     {
         return $this->cache && Preg::isMatch('{^[a-f0-9]{40}$}iD', $identifier);
     }
@@ -87,7 +84,7 @@ abstract class VcsDriver implements VcsDriverInterface
     /**
      * @inheritDoc
      */
-    public function getComposerInformation($identifier)
+    public function getComposerInformation(string $identifier): ?array
     {
         if (!isset($this->infoCache[$identifier])) {
             if ($this->shouldCache($identifier) && $res = $this->cache->read($identifier)) {
@@ -107,11 +104,9 @@ abstract class VcsDriver implements VcsDriverInterface
     }
 
     /**
-     * @param string $identifier
-     *
-     * @return array<string, mixed>|null
+     * @return array<mixed>|null
      */
-    protected function getBaseComposerInformation($identifier)
+    protected function getBaseComposerInformation(string $identifier): ?array
     {
         $composerFileContent = $this->getFileContent('composer.json', $identifier);
 
@@ -121,7 +116,11 @@ abstract class VcsDriver implements VcsDriverInterface
 
         $composer = JsonFile::parseJson($composerFileContent, $identifier . ':composer.json');
 
-        if (empty($composer['time']) && $changeDate = $this->getChangeDate($identifier)) {
+        if ([] === $composer || !is_array($composer)) {
+            return null;
+        }
+
+        if (empty($composer['time']) && null !== ($changeDate = $this->getChangeDate($identifier))) {
             $composer['time'] = $changeDate->format(DATE_RFC3339);
         }
 
@@ -131,10 +130,10 @@ abstract class VcsDriver implements VcsDriverInterface
     /**
      * @inheritDoc
      */
-    public function hasComposerFile($identifier)
+    public function hasComposerFile(string $identifier): bool
     {
         try {
-            return (bool) $this->getComposerInformation($identifier);
+            return null !== $this->getComposerInformation($identifier);
         } catch (TransportException $e) {
         }
 
@@ -148,7 +147,7 @@ abstract class VcsDriver implements VcsDriverInterface
      *
      * @return string The correct type of protocol
      */
-    protected function getScheme()
+    protected function getScheme(): string
     {
         if (extension_loaded('openssl')) {
             return 'https';
@@ -162,12 +161,11 @@ abstract class VcsDriver implements VcsDriverInterface
      *
      * @param string $url The URL of content
      *
-     * @return Response
      * @throws TransportException
      */
-    protected function getContents($url)
+    protected function getContents(string $url): Response
     {
-        $options = isset($this->repoConfig['options']) ? $this->repoConfig['options'] : array();
+        $options = $this->repoConfig['options'] ?? [];
 
         return $this->httpDownloader->get($url, $options);
     }
@@ -175,8 +173,7 @@ abstract class VcsDriver implements VcsDriverInterface
     /**
      * @inheritDoc
      */
-    public function cleanup()
+    public function cleanup(): void
     {
-        return;
     }
 }
