@@ -30,20 +30,20 @@ final class StreamContextFactory
     /**
      * Creates a context supporting HTTP proxies
      *
-     * @param string $url URL the context is to be used for
+     * @param non-empty-string $url URL the context is to be used for
      * @phpstan-param array{http?: array{follow_location?: int, max_redirects?: int, header?: string|array<string>}} $defaultOptions
      * @param  mixed[]           $defaultOptions Options to merge with the default
      * @param  mixed[]           $defaultParams  Parameters to specify on the context
      * @throws \RuntimeException if https proxy required and OpenSSL uninstalled
      * @return resource          Default context
      */
-    public static function getContext(string $url, array $defaultOptions = array(), array $defaultParams = array())
+    public static function getContext(string $url, array $defaultOptions = [], array $defaultParams = [])
     {
-        $options = array('http' => array(
+        $options = ['http' => [
             // specify defaults again to try and work better with curlwrappers enabled
             'follow_location' => 1,
             'max_redirects' => 20,
-        ));
+        ]];
 
         $options = array_replace_recursive($options, self::initOptions($url, $defaultOptions));
         unset($defaultOptions['http']['header']);
@@ -57,7 +57,7 @@ final class StreamContextFactory
     }
 
     /**
-     * @param string  $url
+     * @param non-empty-string $url
      * @param mixed[] $options
      * @param bool    $forCurl When true, will not add proxy values as these are handled separately
      * @phpstan-return array{http: array{header: string[], proxy?: string, request_fulluri: bool}, ssl?: mixed[]}
@@ -67,7 +67,7 @@ final class StreamContextFactory
     {
         // Make sure the headers are in an array form
         if (!isset($options['http']['header'])) {
-            $options['http']['header'] = array();
+            $options['http']['header'] = [];
         }
         if (is_string($options['http']['header'])) {
             $options['http']['header'] = explode("\r\n", $options['http']['header']);
@@ -134,9 +134,9 @@ final class StreamContextFactory
      *
      * @return mixed[]
      */
-    public static function getTlsDefaults(array $options, LoggerInterface $logger = null): array
+    public static function getTlsDefaults(array $options, ?LoggerInterface $logger = null): array
     {
-        $ciphers = implode(':', array(
+        $ciphers = implode(':', [
             'ECDHE-RSA-AES128-GCM-SHA256',
             'ECDHE-ECDSA-AES128-GCM-SHA256',
             'ECDHE-RSA-AES256-GCM-SHA384',
@@ -178,7 +178,7 @@ final class StreamContextFactory
             '!EDH-DSS-DES-CBC3-SHA',
             '!EDH-RSA-DES-CBC3-SHA',
             '!KRB5-DES-CBC3-SHA',
-        ));
+        ]);
 
         /**
          * CN_match and SNI_server_name are only known once a URL is passed.
@@ -186,15 +186,15 @@ final class StreamContextFactory
          *
          * cafile or capath can be overridden by passing in those options to constructor.
          */
-        $defaults = array(
-            'ssl' => array(
+        $defaults = [
+            'ssl' => [
                 'ciphers' => $ciphers,
                 'verify_peer' => true,
                 'verify_depth' => 7,
                 'SNI_enabled' => true,
                 'capture_peer_cert' => true,
-            ),
-        );
+            ],
+        ];
 
         if (isset($options['ssl'])) {
             $defaults['ssl'] = array_replace_recursive($defaults['ssl'], $options['ssl']);
@@ -245,7 +245,7 @@ final class StreamContextFactory
         if (!is_array($header)) {
             $header = explode("\r\n", $header);
         }
-        uasort($header, function ($el): int {
+        uasort($header, static function ($el): int {
             return stripos($el, 'content-type') === 0 ? 1 : -1;
         });
 
