@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -22,7 +22,7 @@ use Composer\Pcre\Preg;
  */
 class Svn
 {
-    const MAX_QTY_AUTH_TRIES = 5;
+    private const MAX_QTY_AUTH_TRIES = 5;
 
     /**
      * @var ?array{username: string, password: string}
@@ -70,12 +70,9 @@ class Svn
     private static $version;
 
     /**
-     * @param string                   $url
-     * @param \Composer\IO\IOInterface $io
-     * @param Config                   $config
      * @param ProcessExecutor          $process
      */
-    public function __construct($url, IOInterface $io, Config $config, ProcessExecutor $process = null)
+    public function __construct(string $url, IOInterface $io, Config $config, ?ProcessExecutor $process = null)
     {
         $this->url = $url;
         $this->io = $io;
@@ -83,10 +80,7 @@ class Svn
         $this->process = $process ?: new ProcessExecutor($io);
     }
 
-    /**
-     * @return void
-     */
-    public static function cleanEnv()
+    public static function cleanEnv(): void
     {
         // clean up env for OSX, see https://github.com/composer/composer/issues/2146#issuecomment-35478940
         Platform::clearEnv('DYLD_LIBRARY_PATH');
@@ -96,16 +90,15 @@ class Svn
      * Execute an SVN remote command and try to fix up the process with credentials
      * if necessary.
      *
-     * @param string $command SVN command to run
-     * @param string $url     SVN url
-     * @param string $cwd     Working directory
-     * @param string $path    Target for a checkout
-     * @param bool   $verbose Output all output to the user
+     * @param string  $command SVN command to run
+     * @param string  $url     SVN url
+     * @param ?string $cwd     Working directory
+     * @param ?string $path    Target for a checkout
+     * @param bool    $verbose Output all output to the user
      *
      * @throws \RuntimeException
-     * @return string
      */
-    public function execute($command, $url, $cwd = null, $path = null, $verbose = false)
+    public function execute(string $command, string $url, ?string $cwd = null, ?string $path = null, bool $verbose = false): string
     {
         // Ensure we are allowed to use this URL by config
         $this->config->prohibitUrlByConfig($url, $this->io);
@@ -123,31 +116,21 @@ class Svn
      * @param bool   $verbose Output all output to the user
      *
      * @throws \RuntimeException
-     * @return string
      */
-    public function executeLocal($command, $path, $cwd = null, $verbose = false)
+    public function executeLocal(string $command, string $path, ?string $cwd = null, bool $verbose = false): string
     {
         // A local command has no remote url
         return $this->executeWithAuthRetry($command, $cwd, '', $path, $verbose);
     }
 
-    /**
-     * @param  string $svnCommand
-     * @param  string $cwd
-     * @param  string $url
-     * @param  string $path
-     * @param  bool   $verbose
-     *
-     * @return ?string
-     */
-    private function executeWithAuthRetry($svnCommand, $cwd, $url, $path, $verbose)
+    private function executeWithAuthRetry(string $svnCommand, ?string $cwd, string $url, ?string $path, bool $verbose): ?string
     {
         // Regenerate the command at each try, to use the newly user-provided credentials
         $command = $this->getCommand($svnCommand, $url, $path);
 
         $output = null;
         $io = $this->io;
-        $handler = function ($type, $buffer) use (&$output, $io, $verbose) {
+        $handler = static function ($type, $buffer) use (&$output, $io, $verbose) {
             if ($type !== 'out') {
                 return null;
             }
@@ -165,7 +148,7 @@ class Svn
         }
 
         $errorOutput = $this->process->getErrorOutput();
-        $fullOutput = implode("\n", array($output, $errorOutput));
+        $fullOutput = trim(implode("\n", [$output, $errorOutput]));
 
         // the error is not auth-related
         if (false === stripos($fullOutput, 'Could not authenticate to server:')
@@ -190,11 +173,7 @@ class Svn
         );
     }
 
-    /**
-     * @param  bool $cacheCredentials
-     * @return void
-     */
-    public function setCacheCredentials($cacheCredentials)
+    public function setCacheCredentials(bool $cacheCredentials): void
     {
         $this->cacheCredentials = $cacheCredentials;
     }
@@ -205,7 +184,7 @@ class Svn
      * @throws \RuntimeException
      * @return \Composer\Util\Svn
      */
-    protected function doAuthDance()
+    protected function doAuthDance(): Svn
     {
         // cannot ask for credentials in non interactive mode
         if (!$this->io->isInteractive()) {
@@ -217,10 +196,10 @@ class Svn
         $this->io->writeError("The Subversion server ({$this->url}) requested credentials:");
 
         $this->hasAuth = true;
-        $this->credentials = array(
+        $this->credentials = [
             'username' => (string) $this->io->ask("Username: ", ''),
             'password' => (string) $this->io->askAndHideAnswer("Password: "),
-        );
+        ];
 
         $this->cacheCredentials = $this->io->askConfirmation("Should Subversion cache these credentials? (yes/no) ");
 
@@ -233,10 +212,8 @@ class Svn
      * @param string $cmd  Usually 'svn ls' or something like that.
      * @param string $url  Repo URL.
      * @param string $path Target for a checkout
-     *
-     * @return string
      */
-    protected function getCommand($cmd, $url, $path = null)
+    protected function getCommand(string $cmd, string $url, ?string $path = null): string
     {
         $cmd = sprintf(
             '%s %s%s -- %s',
@@ -257,10 +234,8 @@ class Svn
      * Return the credential string for the svn command.
      *
      * Adds --no-auth-cache when credentials are present.
-     *
-     * @return string
      */
-    protected function getCredentialString()
+    protected function getCredentialString(): string
     {
         if (!$this->hasAuth()) {
             return '';
@@ -278,9 +253,8 @@ class Svn
      * Get the password for the svn command. Can be empty.
      *
      * @throws \LogicException
-     * @return string
      */
-    protected function getPassword()
+    protected function getPassword(): string
     {
         if ($this->credentials === null) {
             throw new \LogicException("No svn auth detected.");
@@ -293,9 +267,8 @@ class Svn
      * Get the username for the svn command.
      *
      * @throws \LogicException
-     * @return string
      */
-    protected function getUsername()
+    protected function getUsername(): string
     {
         if ($this->credentials === null) {
             throw new \LogicException("No svn auth detected.");
@@ -306,10 +279,8 @@ class Svn
 
     /**
      * Detect Svn Auth.
-     *
-     * @return bool
      */
-    protected function hasAuth()
+    protected function hasAuth(): bool
     {
         if (null !== $this->hasAuth) {
             return $this->hasAuth;
@@ -324,20 +295,16 @@ class Svn
 
     /**
      * Return the no-auth-cache switch.
-     *
-     * @return string
      */
-    protected function getAuthCache()
+    protected function getAuthCache(): string
     {
         return $this->cacheCredentials ? '' : '--no-auth-cache ';
     }
 
     /**
      * Create the auth params from the configuration file.
-     *
-     * @return bool
      */
-    private function createAuthFromConfig()
+    private function createAuthFromConfig(): bool
     {
         if (!$this->config->has('http-basic')) {
             return $this->hasAuth = false;
@@ -347,10 +314,10 @@ class Svn
 
         $host = parse_url($this->url, PHP_URL_HOST);
         if (isset($authConfig[$host])) {
-            $this->credentials = array(
+            $this->credentials = [
                 'username' => $authConfig[$host]['username'],
                 'password' => $authConfig[$host]['password'],
-            );
+            ];
 
             return $this->hasAuth = true;
         }
@@ -360,30 +327,26 @@ class Svn
 
     /**
      * Create the auth params from the url
-     *
-     * @return bool
      */
-    private function createAuthFromUrl()
+    private function createAuthFromUrl(): bool
     {
         $uri = parse_url($this->url);
         if (empty($uri['user'])) {
             return $this->hasAuth = false;
         }
 
-        $this->credentials = array(
+        $this->credentials = [
             'username' => $uri['user'],
             'password' => !empty($uri['pass']) ? $uri['pass'] : '',
-        );
+        ];
 
         return $this->hasAuth = true;
     }
 
     /**
      * Returns the version of the svn binary contained in PATH
-     *
-     * @return string|null
      */
-    public function binaryVersion()
+    public function binaryVersion(): ?string
     {
         if (!self::$version) {
             if (0 === $this->process->execute('svn --version', $output)) {
