@@ -52,14 +52,14 @@ class ShowCommandTest extends TestCase
             'require' => $requires === [] ? new \stdClass : $requires,
         ]);
 
-        $pkg = $this->getPackage('vendor/package', '1.0.0');
+        $pkg = self::getPackage('vendor/package', '1.0.0');
         $pkg->setDescription('description of installed package');
 
         $this->createInstalledJson([
             $pkg,
-            $this->getPackage('outdated/major', '1.0.0'),
-            $this->getPackage('outdated/minor', '1.0.0'),
-            $this->getPackage('outdated/patch', '1.0.0'),
+            self::getPackage('outdated/major', '1.0.0'),
+            self::getPackage('outdated/minor', '1.0.0'),
+            self::getPackage('outdated/patch', '1.0.0'),
         ]);
 
         $appTester = $this->getApplicationTester();
@@ -67,7 +67,7 @@ class ShowCommandTest extends TestCase
         self::assertSame(trim($expected), trim($appTester->getDisplay(true)));
     }
 
-    public function provideShow(): \Generator
+    public static function provideShow(): \Generator
     {
         yield 'default shows installed with version and description' => [
             [],
@@ -123,6 +123,14 @@ outdated/major 1.0.0 ~ 2.0.0',
             ],
         ];
 
+        yield 'outdated deps with --direct show msg if all up to date' => [
+            ['command' => 'outdated', '--direct' => true],
+            'All your direct dependencies are up to date',
+            [
+                'vendor/package' => '*',
+            ],
+        ];
+
         yield 'outdated deps with --major-only only shows major updates' => [
             ['command' => 'outdated', '--major-only' => true],
 'Legend:
@@ -167,6 +175,88 @@ outdated/patch 1.0.0 <highlight>! 1.0.1</highlight>',
         ];
     }
 
+    public function testOutdatedFiltersAccordingToPlatformReqsAndWarns(): void
+    {
+        $this->initTempComposer([
+            'repositories' => [
+                'packages' => [
+                    'type' => 'package',
+                    'package' => [
+                        ['name' => 'vendor/package', 'description' => 'generic description', 'version' => '1.0.0'],
+                        ['name' => 'vendor/package', 'description' => 'generic description', 'version' => '1.1.0', 'require' => ['ext-missing' => '3']],
+                        ['name' => 'vendor/package', 'description' => 'generic description', 'version' => '1.2.0', 'require' => ['ext-missing' => '3']],
+                        ['name' => 'vendor/package', 'description' => 'generic description', 'version' => '1.3.0', 'require' => ['ext-missing' => '3']],
+                    ],
+                ],
+            ],
+        ]);
+
+        $this->createInstalledJson([
+            self::getPackage('vendor/package', '1.1.0'),
+        ]);
+
+        $appTester = $this->getApplicationTester();
+        $appTester->run(['command' => 'outdated']);
+        self::assertSame("<warning>Cannot use vendor/package 1.1.0 as it requires ext-missing 3 which is missing from your platform.
+Legend:
+! patch or minor release available - update recommended
+~ major release available - update possible
+
+Direct dependencies required in composer.json:
+Everything up to date
+
+Transitive dependencies not required in composer.json:
+vendor/package 1.1.0 ~ 1.0.0", trim($appTester->getDisplay(true)));
+
+        $appTester = $this->getApplicationTester();
+        $appTester->run(['command' => 'outdated', '--verbose' => true]);
+        self::assertSame("<warning>Cannot use vendor/package's latest version 1.3.0 as it requires ext-missing 3 which is missing from your platform.
+<warning>Cannot use vendor/package 1.2.0 as it requires ext-missing 3 which is missing from your platform.
+<warning>Cannot use vendor/package 1.1.0 as it requires ext-missing 3 which is missing from your platform.
+Legend:
+! patch or minor release available - update recommended
+~ major release available - update possible
+
+Direct dependencies required in composer.json:
+Everything up to date
+
+Transitive dependencies not required in composer.json:
+vendor/package 1.1.0 ~ 1.0.0", trim($appTester->getDisplay(true)));
+    }
+
+    public function testOutdatedFiltersAccordingToPlatformReqsWithoutWarningForHigherVersions(): void
+    {
+        $this->initTempComposer([
+            'repositories' => [
+                'packages' => [
+                    'type' => 'package',
+                    'package' => [
+                        ['name' => 'vendor/package', 'description' => 'generic description', 'version' => '1.0.0'],
+                        ['name' => 'vendor/package', 'description' => 'generic description', 'version' => '1.1.0'],
+                        ['name' => 'vendor/package', 'description' => 'generic description', 'version' => '1.2.0'],
+                        ['name' => 'vendor/package', 'description' => 'generic description', 'version' => '1.3.0', 'require' => ['php' => '^99']],
+                    ],
+                ],
+            ],
+        ]);
+
+        $this->createInstalledJson([
+            self::getPackage('vendor/package', '1.1.0'),
+        ]);
+
+        $appTester = $this->getApplicationTester();
+        $appTester->run(['command' => 'outdated']);
+        self::assertSame("Legend:
+! patch or minor release available - update recommended
+~ major release available - update possible
+
+Direct dependencies required in composer.json:
+Everything up to date
+
+Transitive dependencies not required in composer.json:
+vendor/package 1.1.0 <highlight>! 1.2.0</highlight>", trim($appTester->getDisplay(true)));
+    }
+
     public function testShowPlatformOnlyShowsPlatformPackages(): void
     {
         $this->initTempComposer([
@@ -181,7 +271,7 @@ outdated/patch 1.0.0 <highlight>! 1.0.1</highlight>',
         ]);
 
         $this->createInstalledJson([
-            $this->getPackage('vendor/package', '1.0.0'),
+            self::getPackage('vendor/package', '1.0.0'),
         ]);
 
         $appTester = $this->getApplicationTester();
@@ -233,10 +323,10 @@ outdated/patch 1.0.0 <highlight>! 1.0.1</highlight>',
         ]);
 
         $this->createInstalledJson([
-            $this->getPackage('zerozero/major', '0.0.1'),
-            $this->getPackage('zero/major', '0.1.0'),
-            $this->getPackage('zero/minor', '0.1.0'),
-            $this->getPackage('zero/patch', '0.1.2'),
+            self::getPackage('zerozero/major', '0.0.1'),
+            self::getPackage('zero/major', '0.1.0'),
+            self::getPackage('zero/minor', '0.1.0'),
+            self::getPackage('zero/patch', '0.1.2'),
         ]);
 
         $appTester = $this->getApplicationTester();
@@ -279,13 +369,13 @@ zerozero/major 0.0.1 ~ 0.0.2', trim($appTester->getDisplay(true)));
             ],
         ]);
 
-        $pkg = $this->getPackage('vendor/installed', '2.0.0');
+        $pkg = self::getPackage('vendor/installed', '2.0.0');
         $pkg->setDescription('description of installed package');
         $this->createInstalledJson([
             $pkg,
         ]);
 
-        $pkg = $this->getPackage('vendor/locked', '3.0.0');
+        $pkg = self::getPackage('vendor/locked', '3.0.0');
         $pkg->setDescription('description of locked package');
         $this->createComposerLock([
             $pkg,
