@@ -33,7 +33,7 @@ class InstalledVersionsTest extends TestCase
         $prop = new \ReflectionProperty('Composer\Autoload\ClassLoader', 'registeredLoaders');
         $prop->setAccessible(true);
         self::$previousRegisteredLoaders = $prop->getValue();
-        $prop->setValue(array());
+        $prop->setValue([]);
     }
 
     public static function tearDownAfterClass(): void
@@ -54,7 +54,7 @@ class InstalledVersionsTest extends TestCase
 
     public function testGetInstalledPackages(): void
     {
-        $names = array(
+        $names = [
             '__root__',
             'a/provider',
             'a/provider2',
@@ -64,15 +64,12 @@ class InstalledVersionsTest extends TestCase
             'foo/impl2',
             'foo/replaced',
             'meta/package',
-        );
+        ];
         $this->assertSame($names, InstalledVersions::getInstalledPackages());
     }
 
     /**
      * @dataProvider isInstalledProvider
-     * @param bool $expected
-     * @param string $name
-     * @param bool $includeDevRequirements
      */
     public function testIsInstalled(bool $expected, string $name, bool $includeDevRequirements = true): void
     {
@@ -81,23 +78,20 @@ class InstalledVersionsTest extends TestCase
 
     public static function isInstalledProvider(): array
     {
-        return array(
-            array(true,  'foo/impl'),
-            array(true,  'foo/replaced'),
-            array(true,  'c/c'),
-            array(false, 'c/c', false),
-            array(true,  '__root__'),
-            array(true,  'b/replacer'),
-            array(false, 'not/there'),
-            array(true,  'meta/package'),
-        );
+        return [
+            [true,  'foo/impl'],
+            [true,  'foo/replaced'],
+            [true,  'c/c'],
+            [false, 'c/c', false],
+            [true,  '__root__'],
+            [true,  'b/replacer'],
+            [false, 'not/there'],
+            [true,  'meta/package'],
+        ];
     }
 
     /**
      * @dataProvider satisfiesProvider
-     * @param bool $expected
-     * @param string $name
-     * @param string $constraint
      */
     public function testSatisfies(bool $expected, string $name, string $constraint): void
     {
@@ -106,38 +100,36 @@ class InstalledVersionsTest extends TestCase
 
     public static function satisfiesProvider(): array
     {
-        return array(
-            array(true,  'foo/impl', '1.5'),
-            array(true,  'foo/impl', '1.2'),
-            array(true,  'foo/impl', '^1.0'),
-            array(true,  'foo/impl', '^3 || ^2'),
-            array(false, 'foo/impl', '^3'),
+        return [
+            [true,  'foo/impl', '1.5'],
+            [true,  'foo/impl', '1.2'],
+            [true,  'foo/impl', '^1.0'],
+            [true,  'foo/impl', '^3 || ^2'],
+            [false, 'foo/impl', '^3'],
 
-            array(true,  'foo/replaced', '3.5'),
-            array(true,  'foo/replaced', '^3.2'),
-            array(false,  'foo/replaced', '4.0'),
+            [true,  'foo/replaced', '3.5'],
+            [true,  'foo/replaced', '^3.2'],
+            [false,  'foo/replaced', '4.0'],
 
-            array(true,  'c/c', '3.0.0'),
-            array(true,  'c/c', '^3'),
-            array(false, 'c/c', '^3.1'),
+            [true,  'c/c', '3.0.0'],
+            [true,  'c/c', '^3'],
+            [false, 'c/c', '^3.1'],
 
-            array(true,  '__root__', 'dev-master'),
-            array(true,  '__root__', '^1.10'),
-            array(false, '__root__', '^2'),
+            [true,  '__root__', 'dev-master'],
+            [true,  '__root__', '^1.10'],
+            [false, '__root__', '^2'],
 
-            array(true,  'b/replacer', '^2.1'),
-            array(false, 'b/replacer', '^2.3'),
+            [true,  'b/replacer', '^2.1'],
+            [false, 'b/replacer', '^2.3'],
 
-            array(true,  'a/provider2', '^1.2'),
-            array(true,  'a/provider2', '^1.4'),
-            array(false, 'a/provider2', '^1.5'),
-        );
+            [true,  'a/provider2', '^1.2'],
+            [true,  'a/provider2', '^1.4'],
+            [false, 'a/provider2', '^1.5'],
+        ];
     }
 
     /**
      * @dataProvider getVersionRangesProvider
-     * @param string $expected
-     * @param string $name
      */
     public function testGetVersionRanges(string $expected, string $name): void
     {
@@ -146,22 +138,20 @@ class InstalledVersionsTest extends TestCase
 
     public static function getVersionRangesProvider(): array
     {
-        return array(
-            array('dev-master || 1.10.x-dev',   '__root__'),
-            array('^1.1 || 1.2 || 1.4 || 2.0',  'foo/impl'),
-            array('2.2 || 2.0',                 'foo/impl2'),
-            array('^3.0',                       'foo/replaced'),
-            array('1.1',                        'a/provider'),
-            array('1.2 || 1.4',                 'a/provider2'),
-            array('2.2',                        'b/replacer'),
-            array('3.0',                        'c/c'),
-        );
+        return [
+            ['dev-master || 1.10.x-dev',   '__root__'],
+            ['^1.1 || 1.2 || 1.4 || 2.0',  'foo/impl'],
+            ['2.2 || 2.0',                 'foo/impl2'],
+            ['^3.0',                       'foo/replaced'],
+            ['1.1',                        'a/provider'],
+            ['1.2 || 1.4',                 'a/provider2'],
+            ['2.2',                        'b/replacer'],
+            ['3.0',                        'c/c'],
+        ];
     }
 
     /**
      * @dataProvider getVersionProvider
-     * @param null|string $expected
-     * @param string $name
      */
     public function testGetVersion(?string $expected, string $name): void
     {
@@ -170,22 +160,20 @@ class InstalledVersionsTest extends TestCase
 
     public static function getVersionProvider(): array
     {
-        return array(
-            array('dev-master',  '__root__'),
-            array(null, 'foo/impl'),
-            array(null, 'foo/impl2'),
-            array(null, 'foo/replaced'),
-            array('1.1.0.0', 'a/provider'),
-            array('1.2.0.0', 'a/provider2'),
-            array('2.2.0.0', 'b/replacer'),
-            array('3.0.0.0', 'c/c'),
-        );
+        return [
+            ['dev-master',  '__root__'],
+            [null, 'foo/impl'],
+            [null, 'foo/impl2'],
+            [null, 'foo/replaced'],
+            ['1.1.0.0', 'a/provider'],
+            ['1.2.0.0', 'a/provider2'],
+            ['2.2.0.0', 'b/replacer'],
+            ['3.0.0.0', 'c/c'],
+        ];
     }
 
     /**
      * @dataProvider getPrettyVersionProvider
-     * @param null|string $expected
-     * @param string $name
      */
     public function testGetPrettyVersion(?string $expected, string $name): void
     {
@@ -194,16 +182,16 @@ class InstalledVersionsTest extends TestCase
 
     public static function getPrettyVersionProvider(): array
     {
-        return array(
-            array('dev-master',  '__root__'),
-            array(null, 'foo/impl'),
-            array(null, 'foo/impl2'),
-            array(null, 'foo/replaced'),
-            array('1.1', 'a/provider'),
-            array('1.2', 'a/provider2'),
-            array('2.2', 'b/replacer'),
-            array('3.0', 'c/c'),
-        );
+        return [
+            ['dev-master',  '__root__'],
+            [null, 'foo/impl'],
+            [null, 'foo/impl2'],
+            [null, 'foo/replaced'],
+            ['1.1', 'a/provider'],
+            ['1.2', 'a/provider2'],
+            ['2.2', 'b/replacer'],
+            ['3.0', 'c/c'],
+        ];
     }
 
     public function testGetVersionOutOfBounds(): void
@@ -214,18 +202,18 @@ class InstalledVersionsTest extends TestCase
 
     public function testGetRootPackage(): void
     {
-        $this->assertSame(array(
+        $this->assertSame([
             'name' => '__root__',
             'pretty_version' => 'dev-master',
             'version' => 'dev-master',
             'reference' => 'sourceref-by-default',
             'type' => 'library',
             'install_path' => $this->root . '/./',
-            'aliases' => array(
+            'aliases' => [
                 '1.10.x-dev',
-            ),
+            ],
             'dev' => true,
-        ), InstalledVersions::getRootPackage());
+        ], InstalledVersions::getRootPackage());
     }
 
     /**
@@ -239,8 +227,6 @@ class InstalledVersionsTest extends TestCase
 
     /**
      * @dataProvider getReferenceProvider
-     * @param null|string $expected
-     * @param string $name
      */
     public function testGetReference(?string $expected, string $name): void
     {
@@ -249,27 +235,27 @@ class InstalledVersionsTest extends TestCase
 
     public static function getReferenceProvider(): array
     {
-        return array(
-            array('sourceref-by-default',  '__root__'),
-            array(null, 'foo/impl'),
-            array(null, 'foo/impl2'),
-            array(null, 'foo/replaced'),
-            array('distref-as-no-source', 'a/provider'),
-            array('distref-as-installed-from-dist', 'a/provider2'),
-            array(null, 'b/replacer'),
-            array(null, 'c/c'),
-        );
+        return [
+            ['sourceref-by-default',  '__root__'],
+            [null, 'foo/impl'],
+            [null, 'foo/impl2'],
+            [null, 'foo/replaced'],
+            ['distref-as-no-source', 'a/provider'],
+            ['distref-as-installed-from-dist', 'a/provider2'],
+            [null, 'b/replacer'],
+            [null, 'c/c'],
+        ];
     }
 
     public function testGetInstalledPackagesByType(): void
     {
-        $names = array(
+        $names = [
             '__root__',
             'a/provider',
             'a/provider2',
             'b/replacer',
             'c/c',
-        );
+        ];
 
         $this->assertSame($names, \Composer\InstalledVersions::getInstalledPackagesByType('library'));
     }
