@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -21,7 +21,7 @@ class JsonFormatterTest extends TestCase
      * Test if \u0119 will get correctly formatted (unescaped)
      * https://github.com/composer/composer/issues/2613
      */
-    public function testUnicodeWithPrependedSlash()
+    public function testUnicodeWithPrependedSlash(): void
     {
         if (!extension_loaded('mbstring')) {
             $this->markTestSkipped('Test requires the mbstring extension');
@@ -29,6 +29,7 @@ class JsonFormatterTest extends TestCase
         $backslash = chr(92);
         $data = '"' . $backslash . $backslash . $backslash . 'u0119"';
         $expected = '"' . $backslash . $backslash . 'ę"';
+        /** @phpstan-ignore-next-line */
         $this->assertEquals($expected, JsonFormatter::format($data, true, true));
     }
 
@@ -36,13 +37,14 @@ class JsonFormatterTest extends TestCase
      * Surrogate pairs are intentionally skipped and not unescaped
      * https://github.com/composer/composer/issues/7510
      */
-    public function testUtf16SurrogatePair()
+    public function testUtf16SurrogatePair(): void
     {
         if (!extension_loaded('mbstring')) {
             $this->markTestSkipped('Test requires the mbstring extension');
         }
 
         $escaped = '"\ud83d\ude00"';
+        /** @phpstan-ignore-next-line */
         $this->assertEquals($escaped, JsonFormatter::format($escaped, true, true));
     }
 }
