@@ -24,12 +24,12 @@ class InstalledRepositoryTest extends TestCase
     public function testFindPackagesWithReplacersAndProviders(): void
     {
         $arrayRepoOne = new InstalledArrayRepository;
-        $arrayRepoOne->addPackage($foo = $this->getPackage('foo', '1'));
-        $arrayRepoOne->addPackage($foo2 = $this->getPackage('foo', '2'));
+        $arrayRepoOne->addPackage($foo = self::getPackage('foo', '1'));
+        $arrayRepoOne->addPackage($foo2 = self::getPackage('foo', '2'));
 
         $arrayRepoTwo = new InstalledArrayRepository;
-        $arrayRepoTwo->addPackage($bar = $this->getPackage('bar', '1'));
-        $arrayRepoTwo->addPackage($bar2 = $this->getPackage('bar', '2'));
+        $arrayRepoTwo->addPackage($bar = self::getPackage('bar', '1'));
+        $arrayRepoTwo->addPackage($bar2 = self::getPackage('bar', '2'));
 
         $foo->setReplaces(['provided' => new Link('foo', 'provided', new MatchAllConstraint())]);
         $bar2->setProvides(['provided' => new Link('bar', 'provided', new MatchAllConstraint())]);
