@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -12,9 +12,7 @@
 
 namespace Composer\Test\Util;
 
-use Composer\Downloader\TransportException;
 use Composer\Util\GitHub;
-use Composer\Util\Http\Response;
 use Composer\Test\TestCase;
 
 /**
@@ -29,13 +27,13 @@ class GitHubTest extends TestCase
     /** @var string */
     private $origin = 'github.com';
 
-    public function testUsernamePasswordAuthenticationFlow()
+    public function testUsernamePasswordAuthenticationFlow(): void
     {
         $io = $this->getIOMock();
         $io
-            ->expects($this->at(0))
+            ->expects($this->atLeastOnce())
             ->method('writeError')
-            ->with($this->message)
+            ->withConsecutive([$this->message])
         ;
         $io
             ->expects($this->once())
@@ -45,15 +43,10 @@ class GitHubTest extends TestCase
         ;
 
         $httpDownloader = $this->getHttpDownloaderMock();
-        $httpDownloader
-            ->expects($this->once())
-            ->method('get')
-            ->with(
-                $this->equalTo($url = sprintf('https://api.%s/', $this->origin)),
-                $this->anything()
-            )
-            ->willReturn(new Response(array('url' => $url), 200, array(), '{}'))
-        ;
+        $httpDownloader->expects(
+            [['url' => sprintf('https://api.%s/', $this->origin), 'body' => '{}']],
+            true
+        );
 
         $config = $this->getConfigMock();
         $config
@@ -72,7 +65,7 @@ class GitHubTest extends TestCase
         $this->assertTrue($github->authorizeOAuthInteractively($this->origin, $this->message));
     }
 
-    public function testUsernamePasswordFailure()
+    public function testUsernamePasswordFailure(): void
     {
         $io = $this->getIOMock();
         $io
@@ -83,11 +76,10 @@ class GitHubTest extends TestCase
         ;
 
         $httpDownloader = $this->getHttpDownloaderMock();
-        $httpDownloader
-            ->expects($this->exactly(1))
-            ->method('get')
-            ->will($this->throwException(new TransportException('', 401)))
-        ;
+        $httpDownloader->expects(
+            [['url' => sprintf('https://api.%s/', $this->origin), 'status' => 401]],
+            true
+        );
 
         $config = $this->getConfigMock();
         $config
@@ -123,20 +115,6 @@ class GitHubTest extends TestCase
         return $this->getMockBuilder('Composer\Config')->getMock();
     }
 
-    /**
-     * @return \PHPUnit\Framework\MockObject\MockObject&\Composer\Util\HttpDownloader
-     */
-    private function getHttpDownloaderMock()
-    {
-        $httpDownloader = $this
-            ->getMockBuilder('Composer\Util\HttpDownloader')
-            ->disableOriginalConstructor()
-            ->getMock()
-        ;
-
-        return $httpDownloader;
-    }
-
     /**
      * @return \PHPUnit\Framework\MockObject\MockObject&\Composer\Config\JsonConfigSource
      */
