@@ -27,7 +27,7 @@ class NoProxyPatternTest extends TestCase
         $this->assertEquals($expected, $matcher->test($url));
     }
 
-    public function dataHostName(): array
+    public static function dataHostName(): array
     {
         $noproxy = 'foobar.com, .barbaz.net';
 
@@ -54,7 +54,7 @@ class NoProxyPatternTest extends TestCase
         $this->assertEquals($expected, $matcher->test($url));
     }
 
-    public function dataIpAddress(): array
+    public static function dataIpAddress(): array
     {
         $noproxy = '192.168.1.1, 2001:db8::52:0:1';
 
@@ -79,7 +79,7 @@ class NoProxyPatternTest extends TestCase
         $this->assertEquals($expected, $matcher->test($url));
     }
 
-    public function dataIpRange(): array
+    public static function dataIpRange(): array
     {
         $noproxy = '10.0.0.0/30, 2002:db8:a::45/121';
 
@@ -104,7 +104,7 @@ class NoProxyPatternTest extends TestCase
         $this->assertEquals($expected, $matcher->test($url));
     }
 
-    public function dataPort(): array
+    public static function dataPort(): array
     {
         $noproxy = '192.168.1.2:81, 192.168.1.3:80, [2001:db8::52:0:2]:443, [2001:db8::52:0:3]:80';
 
